@@ -315,7 +315,8 @@ sinfo_rec_distortion(cpl_parameterlist *config, cpl_frameset *set)
         check_nomsg(sinfo_ima_line_cor(config,set));
     }
 
-    cknull_nomsg(set_fibre_ns=sinfo_frameset_extract(set,RAW_FIBRE_NS));
+    //cknull_nomsg(set_fibre_ns=sinfo_frameset_extract(set,RAW_FIBRE_NS));
+    set_fibre_ns=cpl_frameset_duplicate(set);
     cknull_nomsg(set_flat_ns=sinfo_frameset_extract(set,RAW_FLAT_NS));
     cknull_nomsg(set_wave_ns=sinfo_frameset_extract(set,RAW_WAVE_NS));
     check_nomsg(p=cpl_parameterlist_find(config,"sinfoni.bp.method"));
