@@ -263,7 +263,7 @@ sinfo_utl_ima_line_corr( cpl_parameterlist   *   parlist,
         goto cleanup ;
     }
     raw_set=cpl_frameset_new();
-    ck0_nomsg(sinfo_extract_raw_frames(framelist, &raw_set));
+    sinfo_extract_frames_group_type(framelist,&raw_set,CPL_FRAME_GROUP_RAW);
     n=cpl_frameset_get_size(raw_set);
     if(n<1) {
         sinfo_msg_error("No raw data found in frame list!");
