@@ -74,8 +74,6 @@ static double matrix1[NPAR][NPAR] ;     /* original matrix */
 static double matrix2[NPAR][NPAR] ;     /* inverse of matrix1 */
 static int    nfree ;                   /* number of free parameters */
 static int    parptr[NPAR] ;            /* parameter pointer */
-static float  slopewidth ;              /* initial value for fit parameter 5: 
-                                           width of linear slope */
 
 /*----------------------------------------------------------------------------
  *                    Functions private to this module
@@ -1565,6 +1563,8 @@ sinfo_new_fit_slits_edge_with_estimate ( cpl_image   * lineImage,
     int ilx=0;
     int ily=0;
     float* pidata=NULL;
+    sinfo_msg("input parameters: box_length=%d y_box=% g diff_tol=%g low_pos=%d high_pos=%d",
+              box_length, y_box, diff_tol, low_pos, high_pos );
 
     /* slit_length = SLITLENGTH ; this is too high: 64 */
     slit_length = N_SLITLETS ; /* this is better: 32 */
