@@ -81,6 +81,7 @@ sinfo_disp_calc_N(const disp_data* pdata, double lambda)
     return N;
 
 }
+
 static void 
 sinfo_disp_prepare_data(disp_data* pdata,
                         double lambda0,
@@ -110,6 +111,7 @@ sinfo_disp_prepare_data(disp_data* pdata,
                       pdata->N0,pdata->d1, pdata->d2,  pdata->parallactic_shiftX ,
                       pdata->parallactic_shiftY);
 }
+
 static void 
 sinfo_disp_calc(disp_data* pdata, double lambda, double *shiftx, double *shifty)
 {
@@ -119,17 +121,46 @@ sinfo_disp_calc(disp_data* pdata, double lambda, double *shiftx, double *shifty)
     *shifty = delta * pdata->parallactic_shiftY ;
 }
 
+static void
+sinfo_atmo_rotate_point(double* x_value, double * y_value, double rot_angle)
+{
+    double newx = *x_value * cos(rot_angle) - *y_value * sin(rot_angle);
+    double newy = *x_value * sin(rot_angle) + *y_value * cos(rot_angle);
+    *x_value = newx;
+    *y_value = newy;
+}
+/**
+ * @name sinfo_atm_dispersion_cube
+ *
+ * @short correct object position in cube for atmospheric dispersion
+ *
+ * @param pCube        input imagelist
+ * @param centpix      central plane in the cube CRPIX3
+ * @param centlambda   wavelength of the central plane CRVAL3
+ * @param Tc           temperature in Celsius TEL.AMBI.TEMP
+ * @param Rh           relative humidity in % TEL.AMBI.RHUM
+ * @param airm         airmass for the moment of observation TEL.AMBI.PRES
+ * @param p            atmospheric pressure TEL.AMBI.PRES
+ * @param parallactic  TEL.PARANG
+ * @param pixelscale   could be for SINFONI 0.025, 0.100, 0.250
+ * @param pixelsz      microns per pixel CDELT3
+ *
+ * @doc Performs atmospheric correction using polynomial fit coefficients
+ *
+ * @return CPL_ERROR_NONE if successful else CPL_ERROR_CODE
+ */
+
 cpl_error_code 
 sinfo_atm_dispersion_cube(cpl_imagelist* pCube,
-                          int centpix, // central plane in the cube CRPIX3
-                          double centlambda, // wavelength of the central plane CRVAL3
-                          double Tc, // temperature in Celsius TEL.AMBI.TEMP
-                          double Rh, // relative humidity in % TEL.AMBI.RHUM
-                          double airm, // airmass for the moment of observation TEL.AMBI.PRES
-                          double p, // atmospheric pressure TEL.AMBI.PRES
-                          double parallactic, // TEL.PARANG
-                          double pixelscale, // could be for SINFONI 0.025, 0.100, 0.250
-                          double pixelsz // microns per pixel CDELT3
+                          int centpix,
+                          double centlambda,
+                          double Tc,
+                          double Rh,
+                          double airm,
+                          double p,
+                          double parallactic,
+                          double pixelscale,
+                          double pixelsz
 )
 {
     cpl_error_code err = CPL_ERROR_NONE;
@@ -171,15 +202,20 @@ sinfo_atm_dispersion_cube(cpl_imagelist* pCube,
 
 }
 
+/**
+ * @name sinfo_atmo_load_polynom
+ *
+ * @short set polynomial dispersion coefficients from input table (filename)
+ *
+ * @param filename        input table filename
+ *
+ * @return cpl polynomial with dispersion coefficients
+ */
 
-/*----------------------------------------------------
- * Atmospheric correction using polynomial fit
- *----------------------------------------------------*/
 cpl_polynomial* 
 sinfo_atmo_load_polynom(const char* filename)
 {
-    const char* COL_NAME_TEMPLATE = "col_%d";
-    const char* COL_NAME_VALUE = "value";
+
     cpl_polynomial* poly = NULL;
     cpl_table* ptable = NULL;
 
@@ -196,6 +232,8 @@ sinfo_atmo_load_polynom(const char* filename)
         nrows = cpl_table_get_nrow(ptable);
         expo = cpl_malloc(dim * sizeof(expo[0]));
         memset(&expo[0], 0, dim * sizeof(expo[0]));
+        const char* COL_NAME_TEMPLATE = "col_%d";
+        const char* COL_NAME_VALUE = "value";
         for (i = 0; i < nrows; i++)
         {
             int j = 0;
@@ -224,14 +262,22 @@ sinfo_atmo_load_polynom(const char* filename)
     return poly;
 }
 
-static void 
-sinfo_atmo_rotate_point(double* x_value, double * y_value, double rot_angle)
-{
-    double newx = *x_value * cos(rot_angle) - *y_value * sin(rot_angle);
-    double newy = *x_value * sin(rot_angle) + *y_value * cos(rot_angle);
-    *x_value = newx;
-    *y_value = newy;
-}
+/**
+ * @name sinfo_atmo_apply_cube_polynomial_shift
+ *
+ * @short Applies polynomial dispersion correction to input cube
+ *
+ * @param poly        polynomial correction
+ * @param pCube       cube to correct
+ * @param lambda0     wavelength setting value
+ * @param airmass     airmass value
+ * @param parallactic parallactic coordinate
+ * @param pixelsz     pixel size
+ * @param centpix     central pixel position
+ *
+ * @return cpl polynomial with dispersion coefficients
+ */
+
 
 cpl_imagelist* 
 sinfo_atmo_apply_cube_polynomial_shift(
@@ -244,11 +290,11 @@ sinfo_atmo_apply_cube_polynomial_shift(
                 int centpix)
 {
     cpl_imagelist* retcube = NULL;
-    cpl_error_code 	err = CPL_ERROR_NONE;
+
     cpl_vector* vparams = NULL;
     double * kernel = sinfo_generate_interpolation_kernel("default");
     int cubesize = 0;
-    int i = 0;
+
     // the following two parameters are necessary for computing the shift
     // in case when polynom for H+K band is used for H or K
     double l0_shift_x = 0; // shift for the central point by X
@@ -257,31 +303,32 @@ sinfo_atmo_apply_cube_polynomial_shift(
     vparams = cpl_vector_new(2);
     cpl_vector_set(vparams, 0, airmass);
     cpl_vector_set(vparams, 1, lambda0);
-    err = cpl_error_get_code();
-    if (err == CPL_ERROR_NONE)
+
+    if (CPL_ERROR_NONE == cpl_error_get_code())
     {
+
         l0_shift_y = cpl_polynomial_eval(poly, vparams); // North - South
         l0_shift_x = 0; // (EAST-WEST direction)
         // rotate the shift
         sinfo_atmo_rotate_point(&l0_shift_x, &l0_shift_y, parallactic);
         cubesize = cpl_imagelist_get_size(pCube);
-        err =  cpl_error_get_code();
+
     }
-    if (err == CPL_ERROR_NONE)
+    if (CPL_ERROR_NONE == cpl_error_get_code())
     {
         retcube = cpl_imagelist_new();
-        for (i = 0; i < cubesize; i++)
+        for (int i = 0; i < cubesize; i++)
         {
             // calculate the wavelength
             double lambda = lambda0 - (centpix - i) * pixelsz;
-            double shift_y = 0;
-            double shift_x = 0;
+
 
             cpl_vector_set(vparams, 1, lambda);
             // calc the shift
-            shift_y = cpl_polynomial_eval(poly, vparams); // North - South
-            err = cpl_error_get_code();
-            if (err == CPL_ERROR_NONE)
+
+            double shift_y = cpl_polynomial_eval(poly, vparams); // North - South
+            double shift_x = 0;
+            if (CPL_ERROR_NONE == cpl_error_get_code())
             {
                 double res_shift_x = -(shift_x - l0_shift_x);
                 double res_shift_y = -(shift_y - l0_shift_y);
@@ -295,16 +342,16 @@ sinfo_atmo_apply_cube_polynomial_shift(
                                 res_shift_x, // x shift
                                 res_shift_y, // y shift
                                 kernel);
-                if (err == CPL_ERROR_NONE)
+                if (CPL_ERROR_NONE == cpl_error_get_code())
                 {
-                    err = cpl_imagelist_set(retcube, pimresult, i);
+                    cpl_imagelist_set(retcube, pimresult, i);
                 }
                 else
                 {
                     sinfo_msg_error("Error sinfo_new_shift_image, %s",
                                     cpl_error_get_where());
                 }
-                if (err != CPL_ERROR_NONE)
+                if (CPL_ERROR_NONE != cpl_error_get_code())
                     break;
             }
             else
@@ -312,11 +359,11 @@ sinfo_atmo_apply_cube_polynomial_shift(
                 sinfo_msg_error("Error polynomial_eval, %s",
                                 cpl_error_get_where());
             }
-            if (err != CPL_ERROR_NONE)
+            if (CPL_ERROR_NONE != cpl_error_get_code())
                 break;
         }
     }
-    if (err != CPL_ERROR_NONE)
+    if (CPL_ERROR_NONE != cpl_error_get_code())
     {
         sinfo_free_imagelist(&retcube);
         sinfo_msg_error("Error during shift planes in the cube, %s",
