@@ -64,8 +64,9 @@ parse_section_thresh(badsky_config * cfg, cpl_parameterlist* cpl_cfg);
   @name     sinfo_parse_cpl_input_badsky
   @memo     Parse input from CPL (parameters and set of input frames) 
             to create a blackboard.
-  @param    config    cpl parameter list
+  @param    cpl_cfg    cpl parameter list
   @param    sof       cpl frames list
+  @param    raw       set of frames
   @return   1 newly allocated bad_config blackboard structure.
   @doc      The requested cpl input is parsed and a blackboard object is 
             created, then updated accordingly. Returns NULL in case of error.
