@@ -63,9 +63,6 @@
 
 #include <math.h>
 
-#define H_GEOLAT "ESO TEL GEOLAT"
-#define H_GEOLON "ESO TEL GEOLON"
-#define H_UTC "UTC"
 
 /*-----------------------------------------------------------------------------
   Local functions
