@@ -852,7 +852,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     pos_row      = (int*) cpl_calloc( 3*slit_length, sizeof(int) ) ;
     pos_rowclean = (int*) cpl_calloc( slit_length, sizeof(int) ) ;
 
-
+    //cpl_image_save(lineImage,"line_image.fits",CPL_BPP_IEEE_FLOAT,NULL,CPL_IO_DEFAULT);
     /* -----------------------------------------------------------------------
      * go through the first image columns and the fit parameters and find the 
        line with the highest intensity 
@@ -881,7 +881,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
                 }
             }  
         }
-
+        sinfo_msg("max intensity=%g",max_intensity);
         /* --------------------------------------------------------------------
          * check if the found line is usable and if the neighbouring line 
          * have intensity on near rows in neighbouring slitlets 
@@ -921,7 +921,7 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
         }    
     }
 
-
+    sinfo_msg("agreed=%d",agreed);
 
     if ( agreed == -1 )
     {
@@ -944,14 +944,14 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     position=cpl_calloc(ilx,sizeof(float)) ;
 
     /* was for ( col = 0 ; col < ilx - slit_length/2 ; col++ ) */
+    sinfo_msg("slit_length=%d col_min=%d col_max=%d",
+              slit_length,slit_length/2,ilx-slit_length/2);
+
     for ( col = slit_length/2 ; col < ilx - slit_length/2 ; col++ )
     {
         for ( i = 0 ; i < par[0]->n_params ; i++ )
         {
-            /*
-              printf("p1=%f p2=%f p3=%f\n",
-              par[i]->fit_par[0],par[i]->fit_par[1],par[i]->fit_par[2]);
-             */
+
             if ( par[i]->column == col && par[i]->line == line )
             {
                 if ( par[i]->fit_par[0] > 0.  && 
@@ -960,10 +960,17 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
                 {
                     position[n] = par[i]->fit_par[2] ;
                     old_pos=position[n];
-                    if ( n > 0 && 
-                                    fabs(position[n] - position[n-1]) > y_box &&
-                                    (col-old_col) > (slit_length-SLIT_POS_ERR) )
+
+                    if ( n > 0 && fabs(position[n] - position[n-1]) > y_box &&
+                         ( (old_col == 0) ||
+                           (col-old_col) > (slit_length-SLIT_POS_ERR) ) )
                     {
+		      /*
+                        sinfo_msg("Found Slit Edge n=%d col=%d check1=%g test1=%g",
+                                        n, col,fabs(position[n] - position[n-1]),y_box);
+                        sinfo_msg("check2=%g test2=%g",(col-old_col),(slit_length-SLIT_POS_ERR));
+		      */
+
 
                         old_col=col;
                         sinfo_edge[ed] = col ;
