@@ -52,10 +52,6 @@
 #include "sinfo_local_types.h"
 #include "sinfo_fft_base.h"
 
-static int
-sinfo_sort_slitlets(const int kslit);
-
-
 static int
 sinfo_sort_slitlets_array(const int slit, int* row_index);
 
@@ -667,130 +663,6 @@ sinfo_north_south_test( cpl_image * ns_image,
 }
 
 
-/**
-   @name sinfo_sort_slitlets()
-
-   @brief sort the slitlets in the right spiffi specific way
-
-   @param kslit slit number
-
-   @return spiffi slit index or -1
-*/
-
-static int
-sinfo_sort_slitlets(const int kslit)
-{
-  int slit_index=0;
-
-  switch (kslit)
-    {
-    case 0:
-      slit_index = 8 ;
-      break ;
-    case 1:
-      slit_index = 7 ;
-      break ;
-    case 2:
-      slit_index = 9 ;
-      break ;
-    case 3:
-      slit_index = 6 ;
-      break ;
-    case 4:
-      slit_index = 10 ;
-      break ;
-    case 5:
-      slit_index = 5 ;
-      break ;
-    case 6:
-      slit_index = 11 ;
-      break ;
-    case 7:
-      slit_index = 4 ;
-      break ;
-    case 8:
-      slit_index = 12 ;
-      break ;
-    case 9:
-      slit_index = 3 ;
-      break ;
-    case 10:
-      slit_index = 13 ;
-      break ;
-    case 11:
-      slit_index = 2 ;
-      break ;
-    case 12:
-      slit_index = 14 ;
-      break ;
-    case 13:
-      slit_index = 1 ;
-      break ;
-    case 14:
-      slit_index = 15 ;
-      break ;
-    case 15:
-      slit_index = 0 ;
-      break ;
-    case 16:
-      slit_index = 31 ;
-      break ;
-    case 17:
-      slit_index = 16 ;
-      break ;
-    case 18:
-      slit_index = 30 ;
-      break ;
-    case 19:
-      slit_index = 17 ;
-      break ;
-    case 20:
-      slit_index = 29 ;
-      break ;
-    case 21:
-      slit_index = 18 ;
-      break ;
-    case 22:
-      slit_index = 28 ;
-      break ;
-    case 23:
-      slit_index = 19 ;
-      break ;
-    case 24:
-      slit_index = 27 ;
-      break ;
-    case 25:
-      slit_index = 20 ;
-      break ;
-    case 26:
-      slit_index = 26 ;
-      break ;
-    case 27:
-      slit_index = 21 ;
-      break ;
-    case 28:
-      slit_index = 25 ;
-      break ;
-    case 29:
-      slit_index = 22 ;
-      break ;
-    case 30:
-      slit_index = 24 ;
-      break ;
-    case 31:
-      slit_index = 23 ;
-      break ;
-    default:
-      sinfo_msg_error("wrong slitlet index: couldn't be a "
-                      "spiffi image,  there must be 32 slitlets!") ;
-      return -1 ;
-
-                
-   }
-   return slit_index;
-
-}
-
 /**
    @name sinfo_sord_slitlets_array()
 
