@@ -735,16 +735,28 @@ int  sinfo_compare_tags(
 
 int sinfo_get_ins_set(char* band,int* ins_set){
 
-    if (strcmp(band,"H") == 0) {
+    if ( strcmp(band,"H") == 0 ||
+         strcmp(band,"Hn") == 0 ||
+         strcmp(band,"H_old") == 0 ||
+         strcmp(band,"H_new") == 0 ) {
         *ins_set = 0;
     }
-    else if (strcmp(band,"H+K") == 0) {
+    else if (strcmp(band,"H+K") == 0 ||
+             strcmp(band,"H+Kn") == 0 ||
+             strcmp(band,"H+K_old") == 0 ||
+             strcmp(band,"H+K_new") == 0  ) {
         *ins_set = 1;
     }
-    else if (strcmp(band,"K") == 0) {
+    else if ( strcmp(band,"K") == 0 ||
+              strcmp(band,"Kn") == 0 ||
+              strcmp(band,"K_old") == 0 ||
+              strcmp(band,"K_new") == 0 ) {
         *ins_set = 2;
     }
-    else if (strcmp(band,"J") == 0) {
+    else if ( strcmp(band,"J") == 0 ||
+              strcmp(band,"Jn") == 0 ||
+              strcmp(band,"J_old") == 0 ||
+              strcmp(band,"J_new") == 0  ) {
         *ins_set = 3;
     }
     return 0;
@@ -2856,7 +2868,9 @@ int sinfo_frame_is_dither(cpl_frame * frame)
     int dith_status=1;
     int len=0;
 
-
+    /* TODO: Note that this piece of code is wrong as set dith_status to 0
+     * unless the band ID is wrong. The check on dither status is useless
+     */
     cknull(frame,"Null input frame. Exit!");
 
     cknull_nomsg(strcpy(file,cpl_frame_get_filename(frame)));
@@ -2885,13 +2899,32 @@ int sinfo_frame_is_dither(cpl_frame * frame)
     }
 
     sinfo_free_propertylist(&plist) ;
-
+    //sinfo_msg_warning("band: >%s<",band);
     if (strcmp(band,"H") == 0) {
         if( abs(grat_encoder - GRAT_VAL2_H) <= GRAT_VAL_TOL ) {
             dith_status = 0;
         } else {
             dith_status = 0;
         }
+    } else if (strcmp(band,"Hn") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_H) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    } else if (strcmp(band,"H_new") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_H) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"H_old") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_H) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
     }
     else if (strcmp(band,"H+K") == 0) {
         if( abs(grat_encoder - GRAT_VAL2_HK) <= GRAT_VAL_TOL ) {
@@ -2900,6 +2933,27 @@ int sinfo_frame_is_dither(cpl_frame * frame)
             dith_status = 0;
         }
     }
+    else if (strcmp(band,"H+Kn") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_HK) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"H+K_new") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_HK) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"H+K_old") == 0) {
+            if( abs(grat_encoder - GRAT_VAL2_HK) <= GRAT_VAL_TOL ) {
+                dith_status = 0;
+            } else {
+                dith_status = 0;
+            }
+    }
     else if (strcmp(band,"K") == 0) {
         if( abs(grat_encoder - GRAT_VAL2_K) <= GRAT_VAL_TOL ) {
             dith_status = 0;
@@ -2907,6 +2961,27 @@ int sinfo_frame_is_dither(cpl_frame * frame)
             dith_status = 0;
         }
     }
+    else if (strcmp(band,"Kn") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_K) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"K_new") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_K) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"K_old") == 0) {
+           if( abs(grat_encoder - GRAT_VAL2_K) <= GRAT_VAL_TOL ) {
+               dith_status = 0;
+           } else {
+               dith_status = 0;
+           }
+    }
     else if (strcmp(band,"J") == 0) {
         if( abs(grat_encoder - GRAT_VAL2_J) <= GRAT_VAL_TOL ) {
             dith_status = 0;
@@ -2914,6 +2989,29 @@ int sinfo_frame_is_dither(cpl_frame * frame)
             dith_status = 0;
         }
     }
+    else if (strcmp(band,"Jn") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_J) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"J_new") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_J) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    }
+    else if (strcmp(band,"J_old") == 0) {
+        if( abs(grat_encoder - GRAT_VAL2_J) <= GRAT_VAL_TOL ) {
+            dith_status = 0;
+        } else {
+            dith_status = 0;
+        }
+    } else {
+        sinfo_msg_warning("band: >%s< not recognised! Treated like dither!",band);
+    }
     cleanup:
 
     sinfo_free_propertylist(&plist) ;
