@@ -76,9 +76,6 @@ static cpl_apertures *
 sinfo_distortion_detect_arcs_new(cpl_image* ,cpl_image   **,
                                  int,int,double,int,int,int,int,double,int);
 
-static
-cpl_apertures * sinfo_distortion_detect_arcs(cpl_image *,
-        cpl_image **, int, int, int, int, int, int) ;
 static int
 sinfo_distortion_fill_badzones(cpl_image *, int, int, int, int, double) ;
 static int
@@ -576,155 +573,6 @@ static cpl_apertures * sinfo_distortion_detect_arcs_new(
 
 /**@}*/
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Detect the vertical arcs in an image
-  @param    im          the input image
-  @param    label_im    the output label image
-  @param    arc_sat     Saturation threshold for the arcs
-  @param    max_arc_width   Maximum arc width allowed
-  @param    xmin
-  @param    ymin        Define the zone to take into account
-  @param    xmax
-  @param    ymax
-  @return   The arcs or NULL in error case
-
-  The arcs are expected to be vertical.
- */
-/*---------------------------------------------------------------------------*/
-static cpl_apertures * sinfo_distortion_detect_arcs(
-        cpl_image   *   im,
-        cpl_image   **  label_im,
-        int             arc_sat,
-        int             max_arc_width,
-        int             xmin,
-        int             ymin,
-        int             xmax,
-        int             ymax)
-{
-
-    cpl_image       *   filt_im ;
-    cpl_matrix      *   filter ;
-    cpl_image       *   collapsed ;
-    cpl_mask        *   bin_im ;
-    double              threshold, fillval, median_val, sigma ;
-    int                 min_arclen = 0 ;
-    cpl_apertures   *   det ;
-    cpl_size                 nobj ;
-    int                 ngoodpix ;
-    int                 ny ;
-
-    ny = cpl_image_get_size_y(im) ;
-
-    /* Default values for output parameters */
-    *label_im = NULL ;
-
-    /* Clear zones to be ignored (to avoid false detections) */
-    median_val = cpl_image_get_median_dev(im, &sigma) ;
-    fillval = median_val-sigma/2.0 ;
-    if (sinfo_distortion_fill_badzones(im, xmin, ymin, xmax, ymax,
-                fillval) == -1) {
-        cpl_msg_error(cpl_func, "cannot fill bad zones") ;
-        return NULL ;
-    }
-
-    /* Median vertical filter */
-    filter = cpl_matrix_new(3, 1) ;
-    cpl_matrix_fill(filter, 1.0) ;
-    /* filt_im = cpl_image_filter_median(im, filter) ; */
-    filt_im = cpl_image_duplicate(im) ;
-    cpl_matrix_delete(filter) ;
-
-    /* Subtract a low-pass */
-    if (sinfo_distortion_sub_hor_lowpass(filt_im, ARC_WINDOWSIZE) == -1) {
-        cpl_image_delete(filt_im) ;
-        return NULL ;
-    }
-
-    /* Get relevant stats for thresholding */
-    median_val = cpl_image_get_median_dev(filt_im, &sigma) ;
-
-    /* Correct median_val and sigma if necessary */
-    if (median_val < TRESH_MEDIAN_MIN) median_val = TRESH_MEDIAN_MIN ;
-    if (sigma > TRESH_SIGMA_MAX) sigma = TRESH_SIGMA_MAX ;
-
-    /* Set the threshold */
-    threshold = median_val + sigma * ARC_THRESHFACT ;
-
-    /* Collapse the image */
-    collapsed = cpl_image_collapse_median_create(filt_im, 0, 0, 0) ;
-
-    /* Threshold to keep only the arcs - use of the collapsed image */
-    if (sinfo_distortion_threshold1d(filt_im, median_val,
-                                     collapsed, 0.0)==-1) {
-        cpl_msg_error(cpl_func, "cannot threshold the filtered image") ;
-        cpl_image_delete(filt_im) ;
-        cpl_image_delete(collapsed) ;
-        return NULL ;
-    }
-    cpl_image_delete(collapsed) ;
-
-    /* Binarize the image */
-    bin_im = cpl_mask_threshold_image_create(filt_im, threshold,
-            SINFO_DBL_MAX);
-    cpl_image_delete(filt_im) ;
-    if (bin_im == NULL) {
-        cpl_msg_error(cpl_func, "cannot binarise the image") ;
-        return NULL ;
-    }
-
-    /* Test if there are enough good pixels */
-    ngoodpix = cpl_mask_count(bin_im) ;
-    if (ngoodpix < ARC_MINGOODPIX) {
-        cpl_msg_error(cpl_func, "Too few (%d) white pixels", ngoodpix) ;
-        cpl_mask_delete(bin_im) ;
-        return NULL ;
-    }
-
-    /* Apply a morphological closing to clean the isolated pixels */
-    filter = cpl_matrix_new(3, 3) ;
-    cpl_matrix_fill(filter, 1.0) ;
-    cpl_mask_closing(bin_im, filter) ;
-    cpl_matrix_delete(filter) ;
-
-    /* Labelize pixel map to a label image */
-    *label_im = cpl_image_labelise_mask_create(bin_im, &nobj) ;
-    cpl_mask_delete(bin_im) ;
-
-    /* Compute statistics on objects */
-    if ((det = cpl_apertures_new_from_image(im, *label_im)) == NULL) {
-        cpl_msg_error(cpl_func, "Cannot compute arcs stats") ;
-        cpl_image_delete(*label_im) ;
-        *label_im = NULL ;
-        return NULL ;
-    }
-
-    /* Set min_arclen */
-    min_arclen = (int)(ny / ARC_MINARCLENFACT) ;
-
-    /* Purge non-relevant arcs */
-    if (sinfo_distortion_purge_arcs(im, &det, label_im, min_arclen,
-                max_arc_width, arc_sat) == -1) {
-        cpl_msg_error(cpl_func, "Cannot purge the arcs") ;
-        cpl_image_delete(*label_im) ;
-        *label_im = NULL ;
-        cpl_apertures_delete(det) ;
-        return NULL ;
-    }
-    if (cpl_apertures_get_size(det) < ARC_MINNBARCS) {
-        cpl_msg_error(cpl_func, "Not enough valid arcs (%"
-                      CPL_SIZE_FORMAT " < %d)",
-                cpl_apertures_get_size(det), ARC_MINNBARCS) ;
-        cpl_image_delete(*label_im) ;
-        *label_im = NULL ;
-        cpl_apertures_delete(det) ;
-        return NULL ;
-    }
-
-    /* Return  */
-    return det ;
-}
-
 static int sinfo_distortion_fill_badzones(
         cpl_image   *   im,
         int             xmin,
