@@ -22,24 +22,7 @@
  * $Date: 2011-11-23 17:29:09 $
  * $Revision: 1.6 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.5  2006/10/25 06:46:09  amodigli
- * fixed warnings from static checks
- *
- * Revision 1.4  2006/10/17 11:13:30  amodigli
- * added config.h
- *
- * Revision 1.3  2006/10/16 07:26:23  amodigli
- * shortened line length
- *
- * Revision 1.2  2006/10/04 06:17:45  amodigli
- * added doxygen doc
- *
- * Revision 1.1  2006/08/09 12:20:11  amodigli
- * added sinfo_dump.h sinfo_dump.c
- *
- * Revision 1.2  2005/12/19 16:17:56  jmlarsen
- * Replaced bool -> int
+
  *
  */
 #ifndef SINFO_DUMP_H
@@ -52,30 +35,8 @@
 #include <cpl.h>
 #include <sinfo_cpl_size.h>
 
-cpl_error_code 
-sinfo_print_cpl_propertylist(const cpl_propertylist *pl, 
-                             long low, 
-                             long high);
-
-cpl_error_code 
-sinfo_print_cpl_property(const cpl_property *);
-
-cpl_error_code 
-sinfo_print_cpl_frameset(const cpl_frameset *);
-
-cpl_error_code 
-sinfo_print_cpl_frame(const cpl_frame *);
-
 const char *
 sinfo_tostring_cpl_type(cpl_type t);
 
-const char *
-sinfo_tostring_cpl_frame_type(cpl_frame_type);
-
-const char *
-sinfo_tostring_cpl_frame_group(cpl_frame_group);
-
-const char *
-sinfo_tostring_cpl_frame_level(cpl_frame_level);
 
 #endif /* SINFO_DUMP_H */
