@@ -133,7 +133,7 @@ parse_section_frames(finddist_config * cfg,
    char lamp_status[FILE_NAME_SZ];
    char band[FILE_NAME_SZ];
    int ins_set=0;
-   cpl_table* drs_tab=NULL;
+
    wcal* w=NULL;
    int check=0;
    nstpar* nstp=NULL;
@@ -239,7 +239,7 @@ parse_section_frames(finddist_config * cfg,
     if(NULL != cpl_frameset_find(sof,DRS_SETUP_WAVE)) {
      frame = cpl_frameset_find(sof,DRS_SETUP_WAVE);
         strcpy(cfg -> drs_setup,cpl_frame_get_filename(frame));
-        drs_tab = cpl_table_load(cfg->drs_setup,1,0);
+        cpl_table* drs_tab = cpl_table_load(cfg->drs_setup,1,0);
         w->wstart=cpl_table_get_double(drs_tab,"W_START",ins_set,&check);
         w->wgdisp1=cpl_table_get_double(drs_tab,"W_DISP1",ins_set,&check);
         w->wgdisp2=cpl_table_get_double(drs_tab,"W_DISP2",ins_set,&check);
