@@ -216,6 +216,9 @@ parse_section_frames(flat_config * cfg,
                 /* If the frame has a tag we process it. Else it is an object */
                 //tag= (char*) cpl_frame_get_tag(frame);
                 /* sinfo_msg("frame %s tag =%s \n",name,tag); */
+                sinfo_msg("frame is on %d frame is sky %d",
+                                sinfo_frame_is_on(frame),
+                                sinfo_frame_is_sky(frame));
                 if((sinfo_frame_is_on(frame)  == 0) ||
                                 (sinfo_frame_is_sky(frame)  == 1) )
                 {
@@ -269,10 +272,10 @@ parse_section_frames(flat_config * cfg,
         /* sinfo_msg("frame=%s\n",cfg->framelist[i]); */
     }
 
-    /*
+    /* AMO */
    sinfo_msg("Noff= %d Nobj= %d Nditheroff= %d Nditherobj= %d",
                      noff,nobj,nditheroff,nditherobj);
-     */
+
 
 
     if((nobj<1) && (nditherobj< 1)) {
