@@ -899,6 +899,7 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
         return -1 ;
     }
 
+
     /* -------------------------------------------------------------------
      * find the initial estimates for the free parameters
      */
@@ -1154,15 +1155,20 @@ sinfo_new_fit_2d_gaussian ( cpl_image   * image,
     if ( fit_par[2] <= 0. || fit_par[4] < 0. || fit_par[5] < 0. )
     {
         sinfo_msg_error("sorry, some impossible negative fit results!") ;
+        sinfo_msg_error("amplitude=%g, background=%g, Mxx/denom =%g",
+                        fit_par[2],fit_par[4],fit_par[5]);
         return -1 ;
     }
+
     fit_par[0] += llx ;
     fit_par[1] += lly ;
     if ( fit_par[0] < llx || fit_par[0] >= llx + 2*halfbox_x ||
          fit_par[1] < lly || fit_par[1] >= lly + 2*halfbox_y )
     {
-        sinfo_msg_error("sorry, centroid after the fit "
-                        "outside the fitting box") ;
+        sinfo_msg_error("sorry, 2D-Gaussian (x,y)=(%g,%g) position is outside "
+                        "the fitting box (llx,lly,urx,ury)=(%d,%d,%d,%d)",
+                        fit_par[0],fit_par[1],llx,lly,
+                        llx + 2*halfbox_x,lly + 2*halfbox_y) ;
         return -1 ;
     }
 
