@@ -353,6 +353,7 @@ double sinfo_new_my_median_image(cpl_image* im)
  @return resulting row array
  @note NANs are not considered
 
+TODO: not used
  */
 
 Vector * sinfo_new_mean_of_columns( cpl_image *im )
@@ -404,6 +405,7 @@ Vector * sinfo_new_mean_of_columns( cpl_image *im )
   takes the average of each image column by sorting the column values and
   rejecting the given percentage of the highest and lowest values  [0...1]
 
+TODO: not used
  */
 
 cpl_image * sinfo_new_clean_mean_of_columns( cpl_image *im,
@@ -491,7 +493,7 @@ cpl_image * sinfo_new_clean_mean_of_columns( cpl_image *im,
    @param image, row array
    @return resulting image
    @note NANs values are not considered
-
+TODO: not used
  */
 
 cpl_image * sinfo_new_div_image_by_row( cpl_image *im, Vector *row )
@@ -547,7 +549,7 @@ cpl_image * sinfo_new_div_image_by_row( cpl_image *im, Vector *row )
    @param image, row array
    @return resulting image
    @note NANs values are not considered
-
+TODO: not used
  */
 
 cpl_image * sinfo_new_mult_row_to_image( cpl_image *im, Vector *row )
@@ -1301,6 +1303,7 @@ sinfo_new_thresh_image (cpl_image * im, float lo_cut, float hi_cut )
  The bad pixel is interpolated by the mean of these valid pixels (less than 9)
  or by the sinfo_median of them (more than 8).
 
+TODO: not used
  */
 
 cpl_image * sinfo_new_interpol_image ( cpl_image * im,
@@ -1716,6 +1719,7 @@ cpl_image * sinfo_interpol_source_image ( cpl_image * im,
 @param ly:  image length
 @return  resulting image
 
+TODO: not used
  */
 
 cpl_image * sinfo_new_stack_row_to_image ( Vector * row, int ly )
@@ -1901,6 +1905,7 @@ Stats * sinfo_new_image_stats_on_rectangle ( cpl_image * im,
 @param image: image to normalize
 @return resulting image
 
+TODO: not used
  */
 
 cpl_image * sinfo_new_normalize_to_central_pixel ( cpl_image * image )
@@ -2001,6 +2006,8 @@ cpl_image * sinfo_new_normalize_to_central_pixel ( cpl_image * image )
 
   The returned image is a newly allocated object, it must be deallocated
   using cpl_image_delete().
+
+  TODO: not used
  */
 /*--------------------------------------------------------------------------*/
 
@@ -2244,6 +2251,8 @@ sinfo_new_mpe_shift_image(
 
   The returned image is a newly allocated object, it must be deallocated
   using sinfo_image_delete().
+
+  TODO: not used
  */
 /*--------------------------------------------------------------------------*/
 
@@ -2503,6 +2512,7 @@ sinfo_new_combine_masks ( cpl_image * firstMask, cpl_image * secondMask )
    @param y  y slice pixel value
    @return resulting slice image
 
+TODO: not used
  */
 
 cpl_image * sinfo_new_slice_cube (cpl_imagelist * cube, int x, int y )
@@ -2654,6 +2664,7 @@ cpl_image * sinfo_new_div_images_robust ( cpl_image * im1, cpl_image * im2 )
     return retIm ;
 }
 
+/* TODO: not used */
 cpl_image * sinfo_new_null_edges ( cpl_image * image)
 {
     cpl_image * new=NULL ;
@@ -2704,6 +2715,7 @@ cpl_image * sinfo_new_null_edges ( cpl_image * image)
     return new ;
 }
 
+/* TODO: not used */
 
 void sinfo_new_used_cor_map( cpl_image *im, cpl_image *map)
 {
@@ -2916,6 +2928,8 @@ sinfo_new_shift_image(
 
   The returned image is a newly allocated object, it must be deallocated
   using sinfo_image_delete().
+
+  TODO: not used
  */
 /*--------------------------------------------------------------------------*/
 
@@ -2986,6 +3000,8 @@ sinfo_image_hermite_interpol(cpl_image * inp)
 
   The returned image is a newly allocated object, it must be deallocated
   using sinfo_image_delete().
+
+  TODO: not used
  */
 /*--------------------------------------------------------------------------*/
 
@@ -3051,6 +3067,8 @@ sinfo_image_smooth_y(cpl_image * inp, const int r)
 
   The returned image is a newly allocated object, it must be deallocated
   using sinfo_image_delete().
+
+  TODO: not used
  */
 /*--------------------------------------------------------------------------*/
 
