@@ -74,36 +74,14 @@ CPL_BEGIN_DECLS
 #define PAF_NAME_DET_NDIT                  "DET NDIT"
 #define KEY_HELP_DET_NDIT                  "# of Sub-Integrations"
 
-#define KEY_NAME_NCORRS_NAME               "ESO DET NCORRS NAME"
-#define PAF_NAME_NCORRS_NAME               "DET NCORRS NAME"
-#define KEY_HELP_NCORRS_NAME               "Read-Out Mode Name"
-
-#define KEY_NAME_DET_NDSAMPLES             "ESO DET NDSAMPLES"
-#define KEY_HELP_DET_NDSAMPLES             "# of Non-Dest. Samples"
-#define PAF_NAME_DET_NDSAMPLES             "DET NDSAMPLES"
-
-
 #define KEY_NAME_FILT_NAME                 "ESO INS FILT1 NAME"
 #define PAF_NAME_FILT_NAME                 "INS FILT1 NAME"
 #define KEY_HELP_FILT_NAME                 "Filter name."
 
-#define KEY_NAME_FILT_ID                   "ESO INS FILT1 ID"
-#define PAF_NAME_FILT_ID                   "INS FILT1 ID"
-#define KEY_HELP_FILT_ID                   "Filter unique id."
-
-#define KEY_NAME_GRAT_NAME                 "ESO INS GRAT1 NAME"
-#define PAF_NAME_GRAT_NAME                 "INS GRAT1 NAME"
-#define KEY_HELP_GRAT_NAME                 "Grating common name."
-
 #define KEY_NAME_INS_SETUP                 "ESO INS SETUP ID"
 #define PAF_NAME_INS_SETUP                 "INS SETUP ID"
 #define KEY_HELP_INS_SETUP                 "Instrument setup identifier."
 
-#define KEY_NAME_GRAT_WLEN                 "ESO INS GRAT1 WLEN"
-#define PAF_NAME_GRAT_WLEN                 "INS GRAT1 WLEN"
-#define KEY_HELP_GRAT_WLEN                 "Grating central wavelength [nm]."
-
-
 #define KEY_NAME_PRO_REC1_RAW1_NAME        "ESO PRO REC1 RAW1 NAME"
 
 #define KEY_NAME_LAMP_XE                   "ESO INS1 LAMP1 ST"
@@ -122,22 +100,6 @@ CPL_BEGIN_DECLS
 #define PAF_NAME_PREOPTICS                 "INS OPTI1 NAME"
 #define KEY_HELP_PREOPTICS                 "OPTIi name."
 
-#define KEY_NAME_DPR_TYPE                  "ESO DPR TYPE"
-#define PAF_NAME_DPR_TYPE                  "DPR TYPE"
-#define KEY_HELP_DPR_TYPE                  "Observation type"
-
-#define KEY_NAME_DPR_CATG                  "ESO DPR CATG"
-#define PAF_NAME_DPR_CATG                  "DPR CATG"
-#define KEY_HELP_DPR_CATG                  "Observation category"
-
-#define KEY_NAME_DPR_TECH                  "ESO DPR TECH"
-#define PAF_NAME_DPR_TECH                  "DPR TECH"
-#define KEY_HELP_DPR_TECH                  "Observation technique"
-
-#define KEY_NAME_PIPE_ID                   "ESO PRO REC1 PIPE ID"
-#define PAF_NAME_PIPE_ID                   "PRO REC1 PIPE ID"
-#define KEY_HELP_PIPE_ID                   "Pipeline (unique) identifier"
-
 #define KEY_NAME_PIPEFILE                  "PIPEFILE"
 #define KEY_HELP_PIPEFILE                  "Filename of data product"
 
@@ -145,8 +107,6 @@ CPL_BEGIN_DECLS
 #define PAF_NAME_PRO_TYPE                  "PRO TYPE"
 #define KEY_HELP_PRO_TYPE                  "Product Type"
 
-#define KEY_NAME_PRO_REDLEVEL              "ESO PRO REDLEVEL"
-
 #define KEY_NAME_PRO_CATG                  "ESO PRO CATG"
 #define PAF_NAME_PRO_CATG                  "PRO CATG"
 
@@ -167,23 +127,6 @@ CPL_BEGIN_DECLS
 #define KEY_HELP_ARCFILE                   "Archive file name"
 
 
-#define KEY_NAME_TPL_ID                    "ESO TPL ID"
-#define PAF_NAME_TPL_ID                    "TPL ID"
-#define KEY_HELP_TPL_ID                    "Template sig"
-
-#define KEY_NAME_DATANCOM                  "DATANCOM"
-#define KEY_NAME_PRO_DATANCOM              "ESO PRO DATANCOM"
-#define PAF_NAME_PRO_DATANCOM              "PRO DATANCOM"
-#define KEY_HELP_PRO_DATANCOM              "Number of frames combined"
-
-#define KEY_NAME_PRO_RECID                "ESO PRO REC1 ID"
-#define PAF_NAME_PRO_RECID                "PRO REC1 ID"
-#define KEY_HELP_PRO_RECID                "Pipeline recipe (unique) identifier"
-
-#define KEY_NAME_PRO_DRSID                 "ESO PRO REC1 DRS ID"
-#define PAF_NAME_PRO_DRSID                 "PRO REC1 DRS ID"
-#define KEY_HELP_PRO_DRSID                 "Data Reduction System identifier"
-
 #define KEY_NAME_HPRO_TYPE                 "HIERARCH ESO PRO TYPE"
 #define KEY_HELP_HPRO_TYPE                "product type"
 
@@ -200,8 +143,6 @@ CPL_BEGIN_DECLS
 #define KEY_NAME_HPRO_RECID                "HIERARCH ESO PRO REC ID"
 #define KEY_HELP_HPRO_RECID                "recipe ID"
 
-#define KEY_NAME_HPRO_DRSID                "HIERARCH ESO PRO DRS ID"
-#define KEY_HELP_HPRO_DRSID                "data reduction system ID"
 
 #define KEY_NAME_HPRO_DATANCOM             "HIERARCH ESO PRO DATANCOM"
 #define KEY_NAME_HPRO_DID                  "HIERARCH ESO PRO DID"
@@ -209,19 +150,14 @@ CPL_BEGIN_DECLS
 #define KEY_HELP_HPRO_DID                  "Data dictionary for PRO"
 
 
-#define KEY_NAME_HPRO_DOID                  "HIERARCH ESO PRO DO ID"
-#define KEY_VALUE_HPRO_DOID                 "DO-1_18"
-#define KEY_HELP_HPRO_DOID                  "Data Organizer identification ID"
-
-
-#define KEY_NAME_HPRO_RBSID                  "HIERARCH ESO PRO RBS ID"
-#define KEY_VALUE_HPRO_RBSID                 "RBS-1_11"
-#define KEY_HELP_HPRO_RBSID      "Reduction Block Scheduler identification ID"
-
 #define KEY_NAME_REC1_RAW1_NAME            "ESO PRO REC1 RAW1 NAME"
 
 #define KEY_NAME_GRAT_ENC                  "ESO INS GRAT1 ENC"
 
+#define KEY_NAME_DPR_TYPE                  "ESO DPR TYPE"
+#define PAF_NAME_DPR_TYPE                  "DPR TYPE"
+#define KEY_HELP_DPR_TYPE                  "Observation type"
+
 
 CPL_END_DECLS
 
