@@ -259,7 +259,7 @@ cpl_image * sinfo_new_remove_general_offset( cpl_image * im1,
 
     float* pi1data=NULL;
     float* pi2data=NULL;
-    float* pirdata=NULL;
+
     float* poutdata=NULL;
     float* ptmpdata=NULL;
 
@@ -396,7 +396,7 @@ cpl_image * sinfo_new_remove_general_offset( cpl_image * im1,
        lxr=cpl_image_get_size_x(res_image);
        lyr=cpl_image_get_size_y(res_image);
        */
-       pirdata=cpl_image_get_data_float(res_image);
+       float* pirdata=cpl_image_get_data_float(res_image);
 
 
         for ( i = 0 ; i < (int) lxt*lyt ; i++ )
@@ -434,7 +434,7 @@ cpl_image * sinfo_new_remove_regional_tilt ( cpl_image * im1,
     cpl_image * out_image ;
     cpl_image * filtered  ;
     int i, j, k, npix, nrunning ;
-    pixelvalue a, b, sum, sumx, sumy, sumc, sum2 ;
+    pixelvalue a, b, sum;
     int lx1=0;
     int ly1=0;
     int lx2=0;
@@ -547,10 +547,10 @@ cpl_image * sinfo_new_remove_regional_tilt ( cpl_image * im1,
     
     for ( i = 0 ; i < lxf ; i ++ ) /* one column selected */
     {
-        sumy = 0. ;                   /* yi   */
-        sumc = 0. ;                   /* xiyi */
-        sumx = 0. ;                   /* xi   */
-        sum2 = 0. ;                   /* xi^2 */
+        pixelvalue sumy = 0. ;                   /* yi   */
+        pixelvalue sumc = 0. ;        /* xiyi */
+        pixelvalue sumx = 0. ;                   /* xi   */
+        pixelvalue sum2 = 0. ;                   /* xi^2 */
         npix = 0  ;  
           
         for ( j = 0 ; j < lyf ; j ++ ) 
@@ -628,8 +628,8 @@ cpl_image * sinfo_new_remove_column_offset ( cpl_image * im1,
                                 cpl_image * res_image )
 {
     cpl_image * out_image ;
-    int i, j, npix, nrunning ;
-    pixelvalue sum, sum2, mean, stdev, median1, median2, ratio ;
+    int i, j, nrunning ;
+    pixelvalue mean, stdev, median1, median2, ratio ;
     pixelvalue * column1, * column2 ;
     int lx1=0;
     int ly1=0;
@@ -681,9 +681,9 @@ cpl_image * sinfo_new_remove_column_offset ( cpl_image * im1,
     for ( i = 0 ; i < lx2 ; i ++ ) /* select a column */
     {
         /* statistics on columns */
-        sum  = 0.  ;
-        sum2 = 0. ;
-        npix = 0  ;
+        pixelvalue sum  = 0.  ;
+        pixelvalue sum2 = 0. ;
+        int npix = 0  ;
         for ( j = 0 ; j < ly2 ; j ++ )
         {
             /* first select only the good pixels */
@@ -819,8 +819,8 @@ sinfo_new_remove_residual_tilt ( cpl_image * im2, cpl_image * res_image )
 {
     cpl_image * out_image ;
     cpl_image * residual  ;
-    int i, j, npix ;
-    pixelvalue a, b, sum, sumx, sumy, sumc, sum2, mean, stdev ;
+    int i, j ;
+    pixelvalue a, b, sumx, sumy, sumc, mean, stdev ;
     int lx2=0;
     int ly2=0;
     int rlx=0;
@@ -858,9 +858,9 @@ sinfo_new_remove_residual_tilt ( cpl_image * im2, cpl_image * res_image )
 
     for ( i = 0 ; i < lx2; i++ ) /* select one column */
     {
-        sum  = 0. ;
-        sum2 = 0. ;
-        npix = 0  ;
+        pixelvalue sum  = 0. ;
+        pixelvalue sum2 = 0. ;
+        int npix = 0  ;
         for ( j = 0 ; j < ly2 ; j++ ) 
         {
             /* first select good pixels and derive the mean 
@@ -963,7 +963,7 @@ cpl_image *
 sinfo_new_remove_residual_offset( cpl_image * im2, cpl_image * res_image )
 {
     cpl_image * out_image ;
-    int i, j, npix ;
+    int i, j;
     pixelvalue res_median ;
     pixelvalue * column ;
     int lx2=0;
@@ -1008,7 +1008,7 @@ sinfo_new_remove_residual_offset( cpl_image * im2, cpl_image * res_image )
     
     for ( i = 0 ; i < lx2 ; i++ ) /* select one column */
     {
-        npix = 0  ;
+        int npix = 0  ;
     for (j=0;j<ly2;j++)
         column[j]=0;
 
