@@ -857,6 +857,10 @@ double sinfo_kappa_sigma_array_with_mask(
 		const double* exptimes,
 		int x, int y, double mas_adjustment
 		/*, double* val_msk_sum*/);
+
+cpl_error_code
+sinfo_imagelist_reject_value(cpl_imagelist* iml,cpl_value value);
+
 #endif /*!SINFO_NEW_CUBE_OPS_H*/
 
 
