@@ -726,7 +726,6 @@ sinfo_atm_correction(cpl_imagelist** ppCube, cpl_frameset* sof,
                      double centralLambda_cube, int centralpix_cube)
 {
     cpl_polynomial* poly = NULL;
-    cpl_frame* first_frame = NULL;
     const char* ref_file = NULL;
     cpl_propertylist *plist_cube = NULL;
     cpl_propertylist* ppolylist = NULL;
@@ -736,7 +735,10 @@ sinfo_atm_correction(cpl_imagelist** ppCube, cpl_frameset* sof,
  (don't initialize to NULL!)*/
     cpl_imagelist* outcube = *ppCube;
     /* Get the reference file  */
-    first_frame = cpl_frameset_get_first(sof);
+
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(sof);
+    cpl_frame *first_frame = cpl_frameset_iterator_get(it);
+
     ref_file = cpl_frame_get_filename(first_frame);
     if (ref_file && strlen(ref_file)) {
         /* Get FITS header from reference file */
@@ -795,6 +797,7 @@ sinfo_atm_correction(cpl_imagelist** ppCube, cpl_frameset* sof,
         }
         sinfo_free_propertylist(&plist_cube);
     }
+    cpl_frameset_iterator_delete(it);
 
     return;
 }
