@@ -251,6 +251,9 @@ sinfo_new_find_distortions(const char* plugin_id,
 
     /* find the emission lines in each image column */
     sinfo_new_intarray_set_value(sum_pointer, 0, 0);
+    //cpl_image_save(im, "pippo.fits", CPL_BPP_IEEE_FLOAT, NULL, CPL_IO_DEFAULT);
+    sinfo_msg("minDiff=%f halfWidth=%d sigma=%f",
+              cfg->mindiff,cfg->halfWidth,cfg->sigma);
 
     ck0((check = sinfo_new_find_lines(im,
                     wave,
@@ -267,6 +270,11 @@ sinfo_new_find_distortions(const char* plugin_id,
                     cfg->sigma,
                     sum_pointer )),
         "FindLines failed!");
+    /*
+    for(i=0;i<65;i++) {
+    sinfo_msg("found %d lines",n_found_lines[i]);
+    }
+    */
 
     sinfo_free_table(&tbl_line_list);
 
@@ -286,6 +294,9 @@ sinfo_new_find_distortions(const char* plugin_id,
       fit each line, make a polynomial fit and fit the resulting fit
        coefficients across the columns of the slitlet
      */
+    sinfo_msg("halfWidth=%d minAmplitude=%f maxResidual=%f fwhm=%f sigmaFactor=%f pixeldist=%d pixel tolerance %f",
+               cfg->halfWidth,cfg->minAmplitude, cfg->maxResidual, cfg->fwhm,
+               cfg->sigmaFactor,cfg->pixeldist,cfg->pixel_tolerance);
     cknull(map = sinfo_new_wave_cal(im,
                     par,
                     acoefs,
@@ -386,7 +397,7 @@ sinfo_new_find_distortions(const char* plugin_id,
   sinfo_msg("cfg->devtol=%f\n", cfg->devtol);
   sinfo_msg("cfg->loPos=%d\n", cfg->loPos);
   sinfo_msg("cfg->hiPos=%d\n",cfg->hiPos);
-     */
+    */
     cknull(distances = sinfo_north_south_test(imonind,
                     cfg->nslits,
                     cfg->nshalfWidth,
