@@ -52,6 +52,7 @@
 #include "sinfo_image_ops.h"
 #include "sinfo_utilities.h"
 #include "sinfo_globals.h"
+#include "cpl.h"
 /*----------------------------------------------------------------------------
                                 Defines
  ---------------------------------------------------------------------------*/
@@ -267,6 +268,16 @@ sinfo_new_lamp_flats (const char* plugin_id,
         }
     }
 
+    if ( cpl_imagelist_get_size(list_object) <= 0 )
+    {
+        sinfo_msg_error ("input object list's size 0. Check your input data!") ;
+        sinfo_free_imagelist(&list_object);
+        sinfo_free_frameset(&raw);
+        sinfo_flat_free(&cfg);
+    }
+    cpl_error_ensure(cpl_imagelist_get_size(list_object) > 0,
+                     CPL_ERROR_ILLEGAL_INPUT, return -1,
+                            "input cube of size 0!");
 
     if (nob != cfg->nobj || cfg->noff != nsky ||
                     nobjdith != cfg->nditherobj || nskydith != cfg->nditheroff) {
