@@ -1145,17 +1145,22 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
     sinfo_msg("Take the average of the different cubes");
 
     if (cfg->loReject*cfg->nobj < 1. && cfg->hiReject * cfg->nobj < 1.) {
+      //sinfo_msg("ok0 %d",cpl_imagelist_get_size(list_object));
         check(im_obj = cpl_imagelist_collapse_create(list_object),
                         "Average with rejection failed" );
     } else {
-
+      //sinfo_msg("ok01");
         check_nomsg(no=cpl_imagelist_get_size(list_object));
+        //sinfo_msg("ok02");
         lo_cut=(floor)( cfg->loReject*no+0.5);
         hi_cut=(floor)( cfg->hiReject*no+0.5);
+        //sinfo_msg("ok03");
         check(im_obj=cpl_imagelist_collapse_minmax_create(list_object,
                         lo_cut,hi_cut),"Average with rejection failed" );
+        //sinfo_msg("ok04");
 
     }
+    //sinfo_msg("ok1");
     sinfo_free_imagelist(&list_object);
 
     if (cfg->contains_sky == 1) {
@@ -1190,7 +1195,7 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
         }
         sinfo_free_imagelist(&list_dither_object);
     }
-
+    //sinfo_msg("ok2");
     if (cfg->contains_dither == 1 && nskydith > 0) {
         if (cfg->loReject*nskydith < 1. && cfg->hiReject*nskydith < 1.) {
             check(im_dither_sky = cpl_imagelist_collapse_create( list_dither_sky ),
@@ -1206,7 +1211,7 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
         }
         sinfo_free_imagelist(&list_dither_sky);
     }
-
+    //sinfo_msg("ok3");
     /*
   #---------------------------------------------------------
   # Subtract the resulting off-frame (sky) from the on-frame
@@ -1271,10 +1276,22 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
      */
 
     /* here memory leak */
-    //sinfo_msg("cfg->warpfixInd=%d",cfg->warpfixInd);
+    sinfo_msg("cfg->warpfixInd=%d",cfg->warpfixInd);
+    /* AMO forced this */
+    sinfo_msg("pro catg=%s",frm_pro_ctg);
+
+    /*
+    if(strcmp(frm_pro_ctg,PRO_WAVE_LAMP_STACKED) == 0) {
+       cfg->warpfixInd=0;
+       sinfo_msg("cfg->warpfixInd=%d",cfg->warpfixInd);
+       //exit(0);
+    }
+    */
+
     if (cfg->warpfixInd == 1){
         /*#open ASCII file containing the slope parameter and read it*/
         sinfo_msg("Correct object for distortions");
+        //cpl_image_save(im_obj,"im_obj_before_dist.fits",CPL_BPP_IEEE_FLOAT,NULL,CPL_IO_DEFAULT);
         cknull(int_im_shifted=sinfo_new_image_warp_fits(im_obj,
                         cfg->kernel,
                         cfg->polyFile),
@@ -1282,6 +1299,7 @@ int sinfo_new_prepare_stacked_frames (const char* plugin_id,
 
         sinfo_free_image(&im_obj);
         im_obj = cpl_image_duplicate(int_im_shifted);
+        //cpl_image_save(im_obj,"im_obj_after_dist.fits",CPL_BPP_IEEE_FLOAT,NULL,CPL_IO_DEFAULT);
         if (cfg->contains_dither == 1){
             cknull(int_im_dith_shifted=sinfo_new_image_warp_fits(im_dither,
                             cfg->kernel,
