@@ -230,7 +230,7 @@ sinfo_new_sinc(double x)
 cpl_image *
 sinfo_new_warp_image_generic(
                 cpl_image         *    image_in,
-                char          *    kernel_type,
+                const char        *    kernel_type,
                 cpl_polynomial    *    poly_u,
                 cpl_polynomial    *    poly_v
 )
