@@ -31,6 +31,7 @@
 /*----------------------------------------------------------------------------
                                 Includes
  ---------------------------------------------------------------------------*/
+#include <math.h>
 #include "sinfo_new_wave_cal_slit2.h"
 #include "sinfo_pro_save.h"
 #include "sinfo_pro_types.h"
@@ -444,8 +445,37 @@ sinfo_new_wave_cal_slit2(const char* plugin_id,
             }
 
             cknull_nomsg(qclog_tbl = sinfo_qclog_init());
-            ck0_nomsg(sinfo_qclog_add_int(qclog_tbl,"QC NLINES",n_lines,
-                            "Number of found lines","%d"));
+            int min_lines=n_lines;
+            int min_lines_col=0;
+            int max_lines=0;
+            int max_lines_col=0;
+            int avg_lines=0;
+            for(i=0;i<lx;i++) {
+                if (n_found_lines[i] < min_lines) {
+                    min_lines = n_found_lines[i];
+                    min_lines_col=i;
+                }
+                if (n_found_lines[i] > max_lines) {
+                    max_lines = n_found_lines[i];
+                    max_lines_col=i;
+                }
+            }
+            sinfo_msg("sum=%d",sum);
+
+            avg_lines=ceil(sum/2048.);
+            sinfo_msg("avg=%d",avg_lines);
+
+            sinfo_qclog_add_int(qclog_tbl,"QC NLINES",avg_lines,
+                            "Average number of detected lines","%d");
+            sinfo_qclog_add_int(qclog_tbl,"QC NLINES MIN",min_lines,
+                                       "Minimum number of detected lines","%d");
+            sinfo_qclog_add_int(qclog_tbl,"QC NLINES MAX",max_lines,
+                                       "Maximum number of detected lines","%d");
+
+            sinfo_qclog_add_int(qclog_tbl,"QC NLINES MIN POS",min_lines_col,
+                                        "Minimum number of detected lines","%d");
+            sinfo_qclog_add_int(qclog_tbl,"QC NLINES MAX POS",max_lines_col,
+                                        "Maximum number of detected lines","%d");
 
             for ( i = 0 ; i < par[0] -> n_params ; i++ ) {
 
