@@ -405,9 +405,8 @@ parse_section_skyextraction(object_config * cfg,cpl_parameterlist* cpl_cfg)
 /*-----------------------------------------------------------------*/
 void
 sinfo_objnod_free(object_config ** cfg) {
-  int i=0;
   if(*cfg != NULL) {
-    for(i=0;i<(*cfg)->nframes;i++) {
+    for(int i=0;i<(*cfg)->nframes;i++) {
       if((*cfg)->framelist[i]!=NULL) {
     cpl_free((*cfg)->framelist[i]);
     (*cfg)->framelist[i]=NULL;
