@@ -51,10 +51,6 @@ char * sinfo_paf_query(
                 char    *   filename,
                 char    *   key) ;
 
-static int sinfo_is_paf_file(char * filename) ;
-
-static char * sinfo_strcrop(char * s);
-
 
 /**@{*/
 /**
@@ -64,78 +60,6 @@ static char * sinfo_strcrop(char * s);
  */
 
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Remove blanks at the end of a string.
-  @param    s   String to parse.
-  @return   ptr to statically allocated string.
-
-  This function returns a pointer to a statically allocated string,
-  which is identical to the input string, except that all blank
-  characters at the end of the string have been removed.
-  Do not free or modify the returned string! Since the returned string
-  is statically allocated, it will be modified at each function call
-  (not re-entrant).
- */
-/*---------------------------------------------------------------------------*/
-static char * sinfo_strcrop(char * s)
-{
-    static char l[ASCIILINESZ+1];
-    char * last ;
-
-    if (s==NULL) return NULL ;
-    memset(l, 0, ASCIILINESZ+1);
-    strcpy(l, s);
-    last = l + strlen(l);
-    while (last > l) {
-        if (!isspace((int)*(last-1)))
-            break ;
-        last -- ;
-    }
-    *last = (char)0;
-    return l ;
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    returns 1 if file is in PAF format, 0 else
-  @param    filename name of the file to check
-  @return    int 0, 1, or -1
-  Returns 1 if the file name corresponds to a valid PAF file. Returns
-  0 else. If the file does not exist, returns -1. Validity of the PAF file 
-  is checked with the presence of PAF.HDR.START at the beginning
- */
-/*---------------------------------------------------------------------------*/
-static int sinfo_is_paf_file(char * filename)
-{
-    FILE    *    fp ;
-    int            is_paf ;
-    char        line[ASCIILINESZ] ;
-
-    if (filename==NULL) return -1 ;
-
-    /* Initialize is_paf */
-    is_paf = 0 ;
-
-    /* Open file */
-    if ((fp = fopen(filename, "r"))==NULL) {
-        sinfo_msg_error("cannot open file [%s]", filename) ;
-        return -1 ;
-    }
-
-    /* Parse file */
-    while (fgets(line, ASCIILINESZ, fp) != NULL) {
-        if (line[0] != '#') {
-            if (!strncmp(line, PAF_MAGIC, PAF_MAGIC_SZ)) is_paf = 1 ;
-            (void)fclose(fp) ;
-            return is_paf ;
-        }
-    }
-
-    (void)fclose(fp) ;
-    return is_paf ;
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to DET.MODE.NAME
