@@ -557,337 +557,6 @@ sinfo_get_dummy_obj_sky_stacked_and_cubes(cpl_frameset* obj_set,
 
 }
 
-
-int sinfo_new_sci_stk_frames(cpl_parameterlist* config,
-                             cpl_frameset** set,
-                             const char* recipe_id,
-                             const char** pro_ctg_cube)
-{
-    char tag[FILE_NAME_SZ];
-    char pro_ctg_stack[FILE_NAME_SZ];
-    char outname[FILE_NAME_SZ];
-    char filename[FILE_NAME_SZ];
-
-
-    cpl_frameset * obj_set=NULL;
-    cpl_frameset * sky_set=NULL;
-    cpl_frameset * cdb_set=NULL;
-    cpl_frameset * wrk_set=NULL;
-    cpl_frameset * stk_set=NULL;
-    cpl_frameset * tot_set=NULL;
-    cpl_frame     * obj_frm=NULL;
-    cpl_frame    * sky_frm=NULL;
-    cpl_frame    * cdb_frm=NULL;
-    cpl_frame    * wrk_frm=NULL;
-    cpl_frame    * dup_frm=NULL;
-
-    int nsky=0;
-    int nobj=0;
-    int ncdb=0;
-    int ntot=0;
-    int nstk=0;
-
-    int i=0;
-    int j=0;
-    int k=0;
-    int aj_meth=0;
-
-
-    double mjd_obj=0;
-    double mjd_sky=0;
-    double mjd_sky_frm=0;
-    cpl_parameter* p=NULL;
-    fake* fk=sinfo_fake_new();
-
-    check_nomsg(obj_set=cpl_frameset_new());
-    check_nomsg(sky_set=cpl_frameset_new());
-    check_nomsg(cdb_set=cpl_frameset_new());
-
-    sinfo_extract_obj_frames(*set,obj_set);
-    sinfo_extract_sky_frames(*set,sky_set);
-    sinfo_extract_mst_frames(*set,cdb_set);
-
-
-    cknull(obj_frm = cpl_frameset_get_frame(obj_set,0),
-           "No object frames in input set.");
-
-    strcpy(tag,cpl_frame_get_tag(obj_frm));
-    if(NULL!=sinfo_new_set_obj_procatg(tag)){
-        *pro_ctg_cube=sinfo_new_set_obj_procatg(tag);
-    } else {
-        sinfo_msg_error("Frame tag %s not supported.",tag);
-        goto cleanup;
-    }
-
-
-    if(NULL!=sinfo_new_set_stk_procatg(tag)){
-        strcpy(pro_ctg_stack,sinfo_new_set_stk_procatg(tag));
-    } else {
-        sinfo_msg_error("Frame tag %s not supported.",tag);
-        goto cleanup;
-    }
-
-    nobj=cpl_frameset_get_size(obj_set);
-    nsky=cpl_frameset_get_size(sky_set);
-    ncdb=cpl_frameset_get_size(cdb_set);
-
-    if ((nobj==0) && (nsky==0)) {
-        sinfo_msg_error("Empty input set");
-        goto cleanup;
-    }
-
-
-    if ( (nobj != 0) && (nsky != 0) ) {
-        /* We have either OBJ and SKY: we need to create OBJ-SKY pairs */
-        sinfo_msg("------------------------------") ;
-        sinfo_msg("Generates OBJ-SKY pairs");
-        sinfo_msg("------------------------------") ;
-        check_nomsg(tot_set=cpl_frameset_new());
-        check_nomsg(p=cpl_parameterlist_find(config,
-                        "sinfoni.objnod.autojitter_method"));
-        check_nomsg(cpl_parameter_set_int(p,0));
-        cpl_msg_warning(cpl_func , "******** 1 *********");
-
-
-        for (i=0;i<nobj;i++) {
-
-            check_nomsg(wrk_set=cpl_frameset_new());
-
-            check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
-            mjd_obj=sinfo_get_mjd_obs(obj_frm);
-            check_nomsg(sky_frm=cpl_frameset_get_frame(sky_set,0));
-            mjd_sky=sinfo_get_mjd_obs(sky_frm);
-            strcpy(filename,cpl_frame_get_filename(obj_frm));
-
-
-            for (j=1;j<nsky;j++) {
-                check_nomsg(mjd_sky_frm=sinfo_get_mjd_obs(
-                                cpl_frameset_get_frame(sky_set,j)));
-                if(1000.*(mjd_sky_frm-mjd_obj)*(mjd_sky_frm-mjd_obj) <
-                                1000.*(mjd_sky-    mjd_obj)*(mjd_sky-    mjd_obj) ) {
-                    mjd_sky=mjd_sky_frm;
-                    check_nomsg(sky_frm=cpl_frameset_get_frame(sky_set,j));
-                }
-            }
-
-            strcpy(filename,cpl_frame_get_filename(sky_frm));
-
-
-
-            /* monitors whih obj-sky frames are inserted in each wrk_set */
-            check_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-            check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-            check_nomsg(dup_frm=cpl_frame_duplicate(sky_frm));
-            check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-
-            /* merged CDB frames to work set */
-            for(k=0;k<ncdb;k++) {
-                check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-            }
-
-
-            /* defines a new name for the output stacked frame */
-            snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-            ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,i,fk,recipe_id),
-                "Cannot stack frames");
-
-            check_nomsg(stk_set=cpl_frameset_new());
-            sinfo_contains_frames_kind(wrk_set,stk_set,PRO_STACKED);
-            nstk=cpl_frameset_get_size(stk_set);
-
-            for(k=0;k<nstk;k++) {
-                check_nomsg(wrk_frm=cpl_frameset_get_frame(stk_set,k));
-                check_nomsg(dup_frm = cpl_frame_duplicate(wrk_frm));
-                check_nomsg(cpl_frameset_insert(tot_set,dup_frm));
-            }
-            sinfo_free_frameset(&stk_set);
-            sinfo_free_frameset(&wrk_set);
-
-        }
-
-        ntot=cpl_frameset_get_size(tot_set);
-        for(k=0;k<ntot;k++) {
-            check_nomsg(wrk_frm=cpl_frameset_get_frame(tot_set,k));
-            check_nomsg(dup_frm=cpl_frame_duplicate(wrk_frm));
-            check_nomsg(cpl_frameset_insert(*set,dup_frm));
-        }
-        sinfo_free_frameset(&tot_set);
-
-    }
-
-    if ( (nobj == 0) && (nsky != 0) ) {
-
-        /* ===============================================================
-        SKY FRAMES STACKING
-        =============================================================== */
-
-        {
-            sinfo_msg("------------------------------") ;
-            sinfo_msg("SKY ONLY FRAMES DATA REDUCTION NOT SUPPORTED") ;
-            sinfo_msg("------------------------------") ;
-            goto cleanup;
-        }
-
-    }
-
-
-
-    if ( (nobj != 0) && (nsky == 0) ) {
-
-        /* ===============================================================
-        OBJ FRAMES STACKING
-        =============================================================== */
-        check_nomsg(p = cpl_parameterlist_find(config,
-                        "sinfoni.objnod.autojitter_method"));
-        check_nomsg(aj_meth =  cpl_parameter_get_int(p));
-        if(strcmp(pro_ctg_stack,PRO_PUPIL_LAMP_STACKED) == 0) {
-
-            aj_meth = 0;
-
-        }
-
-        if(aj_meth == 2) {
-
-            sinfo_msg("Dummy sky case");
-            sinfo_msg("Fake sky is coming from median of all objects");
-            cknull(sky_frm = sinfo_new_get_dummy_sky(obj_set),
-                   "Problem to get dummy frame");
-
-            sinfo_msg("------------------------------") ;
-            sinfo_msg("Generates OBJ-SKY pairs");
-            sinfo_msg("------------------------------") ;
-            check_nomsg(tot_set=cpl_frameset_new());
-
-
-
-            for (i=0;i<nobj;i++) {
-
-                check_nomsg(wrk_set=cpl_frameset_new());
-                check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
-                check_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                check_nomsg(dup_frm=cpl_frame_duplicate(sky_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                for(k=0;k<ncdb;k++) {
-                    check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                    check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                }
-
-                snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-                ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,
-                                i,fk,recipe_id),
-                    "Error Stacking frame %d",i);
-
-                check_nomsg(stk_set=cpl_frameset_new());
-                sinfo_contains_frames_kind(wrk_set,stk_set,PRO_STACKED);
-                nstk=cpl_frameset_get_size(stk_set);
-                for(k=0;k<nstk;k++) {
-                    check_nomsg(wrk_frm=cpl_frameset_get_frame(stk_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(wrk_frm));
-                    check_nomsg(cpl_frameset_insert(tot_set,dup_frm));
-                }
-                sinfo_free_frameset(&stk_set);
-                sinfo_free_frameset(&wrk_set);
-
-            }
-            check_nomsg(ntot=cpl_frameset_get_size(tot_set));
-            for(k=0;k<ntot;k++) {
-                check_nomsg(wrk_frm=cpl_frameset_get_frame(tot_set,k));
-                check_nomsg(dup_frm=cpl_frame_duplicate(wrk_frm));
-                check_nomsg(cpl_frameset_insert(*set,dup_frm));
-            }
-            sinfo_free_frameset(&tot_set);
-            sinfo_free_frame(&sky_frm);
-
-        } else if(aj_meth == 1 ) {
-
-            sinfo_msg("Dummy obj-sky case");
-            sinfo_msg("Fake sky is coming from each next object");
-
-            if(nobj > 1) {
-                fk->is_fake_sky=1;
-                ck0(sinfo_new_get_dummy_obj_sky_stacked(obj_set,&(*set),config,
-                                fk,pro_ctg_stack,recipe_id),
-                    "Found error to get obj-sky-stacked frame");
-            } else {
-                sinfo_msg("Only one object frame, no sky");
-                ck0(sinfo_new_stack_frames(config,*set,pro_ctg_stack,0,fk,recipe_id),
-                    "Error stacking frame");
-            }
-
-        } else {
-
-            sinfo_msg("------------------------------") ;
-            sinfo_msg("staks each OBJECT ");
-            sinfo_msg("------------------------------") ;
-            tot_set=cpl_frameset_new();
-
-            for (i=0;i<nobj;i++) {
-
-                check_nomsg(wrk_set=cpl_frameset_new());
-                check_nomsg(obj_frm=cpl_frameset_get_frame(obj_set,i));
-                check_nomsg(dup_frm=cpl_frame_duplicate(obj_frm));
-                check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                for(k=0;k<ncdb;k++) {
-                    check_nomsg(cdb_frm=cpl_frameset_get_frame(cdb_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(cdb_frm));
-                    check_nomsg(cpl_frameset_insert(wrk_set,dup_frm));
-                }
-
-
-                snprintf(outname,MAX_NAME_SIZE-1,"%s%d%s","out_stack",i,".fits");
-                ck0(sinfo_new_stack_frames(config,wrk_set,pro_ctg_stack,
-                                i,fk,recipe_id),"Error stacking frame %d",i);
-
-                check_nomsg(stk_set=cpl_frameset_new());
-                sinfo_contains_frames_kind(wrk_set,stk_set,PRO_STACKED);
-                check_nomsg(nstk=cpl_frameset_get_size(stk_set));
-                for(k=0;k<nstk;k++) {
-                    check_nomsg(wrk_frm=cpl_frameset_get_frame(stk_set,k));
-                    check_nomsg(dup_frm=cpl_frame_duplicate(wrk_frm));
-                    check_nomsg(cpl_frameset_insert(tot_set,dup_frm));
-                }
-                sinfo_free_frameset(&stk_set);
-                sinfo_free_frameset(&wrk_set);
-
-            }
-
-            check_nomsg(ntot=cpl_frameset_get_size(tot_set));
-            for(k=0;k<ntot;k++) {
-                check_nomsg(wrk_frm=cpl_frameset_get_frame(tot_set,k));
-                check_nomsg(dup_frm=cpl_frame_duplicate(wrk_frm));
-                check_nomsg(cpl_frameset_insert(*set,dup_frm));
-            }
-            sinfo_free_frameset(&tot_set);
-        }
-    }
-
-    sinfo_free_frameset(&obj_set);
-    sinfo_free_frameset(&sky_set);
-    sinfo_free_frameset(&cdb_set);
-    sinfo_fake_delete(&fk);
-
-    return 0;
-
-
-
-    cleanup:
-
-    sinfo_free_frame(&sky_frm);
-    sinfo_free_frameset(&wrk_set);
-    sinfo_free_frameset(&tot_set);
-    sinfo_free_frameset(&obj_set);
-    sinfo_free_frameset(&sky_set);
-    sinfo_free_frameset(&cdb_set);
-    sinfo_fake_delete(&fk);
-    return -1;
-
-}
-
-
 int sinfo_cub_stk_frames(cpl_parameterlist* config,
                          cpl_frameset** set,
                          const char* recipe_id,
