@@ -961,7 +961,8 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
 
         float bkg_tot=0.;
 
-        if(qc_info==1) {
+        if(qc_info==0) {
+
            sinfo_new_fit_2d_gaussian(i_img,gfit_par,
                                      gderv_par,gmpar,llx,lly,
                                      halfbox_x,halfbox_y,check2);
@@ -975,11 +976,11 @@ cpl_image * sinfo_new_optimal_extraction_from_cube( cpl_imagelist * cube,
                 {
           
                     weighted_sum += weight[col][row] * (pidata[col+row*ilx] - 
-                                    fit_par[3]);
+                                    gfit_par[3]);
             
-                    counts_bkg += (pidata[col+row*ilx] - fit_par[3]);
+                    counts_bkg += (pidata[col+row*ilx] - gfit_par[3]);
                     counts_tot += (pidata[col+row*ilx]);
-                    bkg_tot += fit_par[3];
+                    bkg_tot += gfit_par[3];
             
                 } 
             }
