@@ -150,7 +150,7 @@ parse_section_frames(stack_config_n * cfg,
    int                     found_dither ;
    int                     found_dark   ;
     int nraw=0;
-    int nsof=0;
+   //int nsof=0;
 
    cpl_frame* frame   = NULL;
 
@@ -161,7 +161,7 @@ parse_section_frames(stack_config_n * cfg,
    char* tag=NULL;
    char* do_class=NULL;
   
-   nsof    = cpl_frameset_get_size(sof);
+   //nsof    = cpl_frameset_get_size(sof);
 
 
    do_class=fk->pro_class;
