@@ -70,7 +70,6 @@ static int
 sinfo_dfs_files_dont_exist(cpl_frameset *frameset)
 {
     const char *func = "dfs_files_dont_exist";
-    cpl_frame *frame;
 
     if (frameset == NULL ) {
         cpl_error_set(func, CPL_ERROR_NULL_INPUT);
@@ -81,7 +80,8 @@ sinfo_dfs_files_dont_exist(cpl_frameset *frameset)
         return 0;
     }
 
-    frame = cpl_frameset_get_first(frameset);
+    cpl_frameset_iterator* it = cpl_frameset_iterator_new(frameset);
+    cpl_frame *frame = cpl_frameset_iterator_get(it);
 
     while (frame) {
         if (access(cpl_frame_get_filename(frame), F_OK)) {
@@ -90,10 +90,13 @@ sinfo_dfs_files_dont_exist(cpl_frameset *frameset)
                             cpl_frame_get_tag(frame));
             cpl_error_set(func, CPL_ERROR_FILE_NOT_FOUND);
         }
+        cpl_frameset_iterator_advance(it, 1);
+        frame = cpl_frameset_iterator_get(it);
 
-        frame = cpl_frameset_get_next(frameset);
     }
 
+    cpl_frameset_iterator_delete(it);
+
     if (cpl_error_get_code())
         return 1;
 
