@@ -32,62 +32,6 @@
  */
 
 
-/*----------------------------------------------------------------------------*/
-/**
-  @brief    Convert a vector to a 1d image
-  @param    vector to convert
-  @param    type   of image
-
-  @return   a new allocated 1d image whose elements are the same as the vector
-  @em The image need to be allocated .
-
- */
-/*----------------------------------------------------------------------------*/
-/* TODO: not used */
-cpl_image*
-sinfo_vector_to_image(const cpl_vector* vector,cpl_type type)
-{
-    int i=0;
-    cpl_image* image=NULL;
-    int size=0;
-    const double* pv=NULL;
-    int* pi=NULL;
-    float* pf=NULL;
-    double* pd=NULL;
-
-
-    size=cpl_vector_get_size(vector);
-    image=cpl_image_new(size,1,type);
-    pv=cpl_vector_get_data_const(vector);
-    if(type == CPL_TYPE_INT) {
-        pi=cpl_image_get_data_int(image);
-        for(i=0;i<size;i++) {
-            pi[i]=pv[i];
-        }
-    } else if (type == CPL_TYPE_FLOAT) {
-        pf=cpl_image_get_data_float(image);
-        for(i=0;i<size;i++) {
-            pf[i]=pv[i];
-        }
-    } else if (type == CPL_TYPE_DOUBLE) {
-        pd=cpl_image_get_data_double(image);
-        for(i=0;i<size;i++) {
-            pd[i]=pv[i];
-        }
-    } else {
-        assure( 0, CPL_ERROR_INVALID_TYPE,
-                        "No CPL type to represent BITPIX = %d", type);
-    }
-
-    cleanup:
-    if (cpl_error_get_code() != CPL_ERROR_NONE){
-        sinfo_free_image(&image);
-    }
-
-    return image;
-
-}
-
 
 cpl_error_code
 sinfo_ima_line_cor(cpl_parameterlist * parlist, cpl_frameset* in)
@@ -161,56 +105,11 @@ sinfo_ima_line_cor(cpl_parameterlist * parlist, cpl_frameset* in)
     return cpl_error_get_code();
 
 }
-/* TODO: not used */
-int
-sinfo_table_column_dump(cpl_table* t, const char* name, cpl_type type)
+
+int sinfo_new_intarray_get_value( int * array, int i )
 {
-    int nrow=0;
-    int i=0;
-    int* pi=NULL;
-    float* pf=NULL;
-    double* pd=NULL;
-    char** ps=NULL;
-
-    nrow=cpl_table_get_nrow(t);
-
-    switch(type) {
-
-    case CPL_TYPE_INT:
-        pi=cpl_table_get_data_int(t,name);
-        for(i=0;i<nrow;i++) {
-            sinfo_msg("val=%d",pi[i]);
-        }
-        break;
-    case CPL_TYPE_FLOAT:
-        pf=cpl_table_get_data_float(t,name);
-        for(i=0;i<nrow;i++) {
-            sinfo_msg("val=%g",pf[i]);
-        }
-        break;
-    case CPL_TYPE_DOUBLE:
-        pd=cpl_table_get_data_double(t,name);
-        for(i=0;i<nrow;i++) {
-            sinfo_msg("val=%g",pd[i]);
-        }
-        break;
-    case CPL_TYPE_STRING:
-        ps=cpl_table_get_data_string(t,name);
-        for(i=0;i<nrow;i++) {
-            sinfo_msg("val=%s",ps[i]);
-        }
-        break;
-    default:
-        sinfo_msg_error("Wrong column type");
-        cpl_error_set(cpl_func, CPL_ERROR_TYPE_MISMATCH);
-        return 0;
-
-    }
-    return 0;
+    return array[i] ;
 }
-
-
-
 /**
 @name sinfo_table_shift_column_spline3
 @param shift a table of an double shift
@@ -539,17 +438,6 @@ void sinfo_new_destroy_array(float ** array)
         *array = NULL;
     }
 }
-/* TODO: not used */
-void sinfo_new_destroy_stringarray(char ** array, int size_x)
-{
-    int i ;
-
-    for ( i = 0 ; i < size_x ; i++ )
-    {
-        cpl_free( array[i] ) ;
-    }
-    cpl_free( array ) ;
-}
 
 void sinfo_new_destroy_2Dintarray(int *** array, int size_x)
 {
@@ -685,21 +573,6 @@ void sinfo_new_destroy_intarray(int ** array)
     cpl_free( *array ) ;
     *array=NULL;
 }
-/* TODO: not used */
-int sinfo_new_intarray_get_value( int * array, int i )
-{
-    return array[i] ;
-}
-/* TODO: not used */
-float sinfo_new_Stats_get_cleanstdev(Stats * stats)
-{
-    return stats -> cleanstdev ;
-}
-/* TODO: not used */
-float sinfo_new_Stats_get_cleanmean(Stats * stats)
-{
-    return stats -> cleanmean ;
-}
 
 char * sinfo_new_get_basename(const char *filename)
 {
@@ -1153,13 +1026,7 @@ sinfo_image_filter_linear(const cpl_image *img, const cpl_matrix * mx)
     return sinfo_image_filter_mode(img, mx, CPL_FILTER_LINEAR);
 
 }
-/* TODO: not used */
-cpl_image * sinfo_image_filter_linear2(const cpl_image *img,
-                                       const cpl_matrix * mx)
-{
-    return sinfo_image_filter_wrapper(img, mx, CPL_FILTER_LINEAR);
 
-}
 
 
 cpl_image * sinfo_image_filter_median(const cpl_image * img,
