@@ -124,13 +124,6 @@
 #include "sinfo_globals.h"
 CPL_BEGIN_DECLS
 
-
-cpl_image*
-sinfo_vector_to_image(const cpl_vector* vector,cpl_type type);
-
-int
-sinfo_table_column_dump(cpl_table* t, const char* name, cpl_type type);
-
 cpl_table*
 sinfo_table_shift_column_spline3(cpl_table* t,
                                  const char* col,
@@ -155,7 +148,7 @@ sinfo_ima_line_cor(cpl_parameterlist * parlist, cpl_frameset* in);
 void sinfo_new_array_set_value( float * array, float value, int i );
 float sinfo_new_array_get_value( float * array, int i );
 void sinfo_new_destroy_array(float ** array);
-void sinfo_new_destroy_stringarray(char ** array, int size_x);
+
 void sinfo_new_intarray_set_value( int * array, int value, int i );
 void sinfo_new_array2D_set_value( float ** array, float value, int x, int y );
 void sinfo_new_destroy_2Dintarray(int *** array, int size_x);
@@ -164,14 +157,13 @@ void sinfo_new_destroy_2Ddoublearray(double *** array, int size_x);
 void sinfo_new_destroy_intarray(int ** array);
 void sinfo_new_destroy_doublearray(double * array);
 void sinfo_new_doublearray_set_value( double * array, double value, int i );
-int sinfo_new_intarray_get_value( int * array, int i );
+
 int * sinfo_new_intarray( int size);
 int ** sinfo_new_2Dintarray( int size_x, int size_y);
 double ** sinfo_new_2Ddoublearray( int size_x, int size_y);
 char * sinfo_new_get_rootname(const char * filename);
 char * sinfo_new_get_basename(const char *filename);
-float sinfo_new_Stats_get_cleanstdev(Stats * stats);
-float sinfo_new_Stats_get_cleanmean(Stats * stats);
+
 float sinfo_new_array2D_get_value( float ** array, int x, int y );
 float * sinfo_new_floatarray( int size);
 float ** sinfo_new_2Dfloatarray( int size_x, int size_y);
@@ -193,6 +185,7 @@ double sinfo_spline_hermite(double xp,
                             const double *y,
                                   int n,
                                   int *istart );
+int sinfo_new_intarray_get_value( int * array, int i );
 
 cpl_error_code update_bad_pixel_map(cpl_image* im);
 /* replacement of deprecated functions */
@@ -208,7 +201,6 @@ cpl_polynomial * sinfo_polynomial_fit_1d_create(
         );
 cpl_image * sinfo_image_filter_median(const cpl_image *, const cpl_matrix *);
 cpl_image * sinfo_image_filter_linear(const cpl_image *, const cpl_matrix *);
-cpl_image * sinfo_image_filter_linear2(const cpl_image *, const cpl_matrix *);
 CPL_END_DECLS
 
 #endif
