@@ -361,11 +361,11 @@ sinfo_auto_size_cube(float* offsetx,
   float min_offy=0;
   float max_offy=0;
 
-  cpl_ensure(offsetx  != NULL, CPL_ERROR_ILLEGAL_INPUT, NULL);
-  cpl_ensure(offsety  != NULL, CPL_ERROR_ILLEGAL_INPUT, NULL);
-  cpl_ensure(nframes > 0, CPL_ERROR_ILLEGAL_INPUT, NULL);
-  cpl_ensure(*size_x >= 64, CPL_ERROR_ILLEGAL_INPUT, NULL);
-  cpl_ensure(*size_y >= 64, CPL_ERROR_ILLEGAL_INPUT, NULL);
+  cpl_ensure(offsetx  != NULL, CPL_ERROR_ILLEGAL_INPUT, -1);
+  cpl_ensure(offsety  != NULL, CPL_ERROR_ILLEGAL_INPUT, -1);
+  cpl_ensure(nframes > 0, CPL_ERROR_ILLEGAL_INPUT, -1);
+  cpl_ensure(*size_x >= 64, CPL_ERROR_ILLEGAL_INPUT, -1);
+  cpl_ensure(*size_y >= 64, CPL_ERROR_ILLEGAL_INPUT, -1);
 
   sinfo_msg ("Computation of output cube size") ;
   sinfo_get_xy_min_max(nframes, offsetx, offsety,&min_offx,&max_offx,
@@ -729,8 +729,10 @@ sinfo_new_set_wcs_cube(cpl_imagelist* cub, const char* name, double clambda,
   }
 
   sinfo_new_change_plist_cube(plist, clambda, dis, cpix, cx, cy) ;
+
   sinfo_plist_set_extra_keys(plist,"IMAGE","DATA","RMSE",
 			     "DATA","ERRS","QUAL",0);
+
   if (cpl_imagelist_save(cub, name, CPL_BPP_IEEE_FLOAT,
                          plist,CPL_IO_DEFAULT)!=CPL_ERROR_NONE) {
     sinfo_msg_error( "Cannot save the product %s",name);
@@ -738,6 +740,7 @@ sinfo_new_set_wcs_cube(cpl_imagelist* cub, const char* name, double clambda,
     return -1 ;
   }
   cpl_propertylist_delete(plist) ;
+
   return 0;
 
 }
@@ -777,10 +780,13 @@ sinfo_set_wcs_cal_image(cpl_image* img,
 
   sinfo_msg("crpix1=%g crval1=%g cdelt1=%g",crpix1,crval1,cdelt1);
   sinfo_set_coord1(&plist,crpix1,crval1,cdelt1,0);
+
   sinfo_msg("crpix2=%g crval2=%g cdelt2=%g",crpix2,crval2,cdelt2);
   sinfo_set_coord2(&plist,crpix2,crval2,cdelt2,0);
+
   cpl_propertylist_erase_regexp(plist, "^CDELT*",0);
 
+
   double cd1_1=0;
   double cd1_2=0;
   double cd2_1=0;
@@ -798,6 +804,7 @@ sinfo_set_wcs_cal_image(cpl_image* img,
     cpl_propertylist_delete(plist) ;
     return -1 ;
   }
+
   cpl_propertylist_delete(plist) ;
   return 0;
 
@@ -979,36 +986,47 @@ sinfo_set_coord1(cpl_propertylist** plist,
                  const int is_science)
 {
 
+
+
     if(is_science) {
-       cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
-       cpl_propertylist_insert_after_string(*plist,"EXPTIME","CTYPE1","RA---TAN");
-       cpl_propertylist_set_comment(*plist, "CTYPE1", "Projected Rectascension");
+        cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
+        cpl_propertylist_insert_after_string(*plist,"MJD-OBS","CTYPE1","RA---TAN");
+        cpl_propertylist_set_comment(*plist, "CTYPE1", "Projected Rectascension");
     } else {
         cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
-        cpl_propertylist_insert_after_string(*plist,"EXPTIME","CTYPE1","PIPXEL");
+        cpl_propertylist_insert_after_string(*plist,"MJD-OBS","CTYPE1","PIPXEL");
         cpl_propertylist_set_comment(*plist, "CTYPE1", "pixel unit");
     }
 
+
+
     cpl_propertylist_erase_regexp(*plist, "^CRPIX1",0);
     cpl_propertylist_insert_after_double(*plist,"CTYPE1","CRPIX1", crpix1) ;
     cpl_propertylist_set_comment(*plist, "CRPIX1","Reference pixel in RA" ) ;
 
+
+
     cpl_propertylist_erase_regexp(*plist, "^CRVAL1",0);
     cpl_propertylist_insert_after_double(*plist, "CRPIX1", "CRVAL1", crval1 ) ;
     cpl_propertylist_set_comment(*plist, "CRVAL1","Reference RA" ) ;
 
+
+
     cpl_propertylist_erase_regexp(*plist, "^CDELT1",0);
     cpl_propertylist_insert_after_double(*plist,"CRVAL1","CDELT1",cdelt1 ) ;
     cpl_propertylist_set_comment(*plist, "CDELT1","pixel scale" ) ;
+
+
     if(is_science) {
-       cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
-       cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "deg" ) ;
-       cpl_propertylist_set_comment(*plist, "CUNIT1","RA-UNIT" ) ;
+        cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
+        cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "deg" ) ;
+        cpl_propertylist_set_comment(*plist, "CUNIT1","RA-UNIT" ) ;
     } else {
         cpl_propertylist_erase_regexp(*plist, "^CUNIT1",0);
         cpl_propertylist_insert_after_string(*plist, "CDELT1",  "CUNIT1", "PIXEL" ) ;
         cpl_propertylist_set_comment(*plist, "CUNIT1","pixel unit" ) ;
     }
+
     return;
 }
 
@@ -1028,6 +1046,7 @@ sinfo_set_coord2(cpl_propertylist** plist,
                  const double cdelt2,
                  const int is_science)
 {
+
     if(is_science) {
         cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
         cpl_propertylist_insert_after_string(*plist,"CUNIT1","CTYPE2","DEC--TAN");
@@ -1037,17 +1056,23 @@ sinfo_set_coord2(cpl_propertylist** plist,
         cpl_propertylist_insert_after_string(*plist,"CUNIT1","CTYPE2","PIXEL");
         cpl_propertylist_set_comment(*plist, "CTYPE2", "pixel unit") ;
     }
+
+
     cpl_propertylist_erase_regexp(*plist, "^CRPIX2",0);
     cpl_propertylist_insert_after_double(*plist,"CTYPE2","CRPIX2",crpix2 ) ;
     cpl_propertylist_set_comment(*plist, "CRPIX2", "Reference pixel in DEC") ;
 
+
     cpl_propertylist_erase_regexp(*plist,"^CRVAL2",0);
     cpl_propertylist_insert_after_double(*plist,"CRPIX2","CRVAL2",crval2) ;
     cpl_propertylist_set_comment(*plist,"CRVAL2","Reference DEC") ;
 
+
     cpl_propertylist_erase_regexp(*plist,"^CDELT2",0);
     cpl_propertylist_insert_after_double(*plist,"CRVAL2","CDELT2",cdelt2 ) ;
     cpl_propertylist_set_comment(*plist,"CDELT2","pixel scale") ;
+
+
     if(is_science) {
         cpl_propertylist_erase_regexp(*plist,"^CUNIT2",0);
         cpl_propertylist_insert_after_string(*plist,"CDELT2","CUNIT2", "deg" ) ;
@@ -1076,30 +1101,43 @@ sinfo_set_coord3(cpl_propertylist** plist,
                  const double crval3,
                  const double cdelt3)
 {
-    cpl_propertylist_erase_regexp(*plist, "^CTYPE3",0);
-    cpl_propertylist_insert_after_string(*plist,"EXPTIME", "CTYPE3", "WAVE" ) ;
+
+    if(cpl_propertylist_has(*plist,"CTYPE3")) {
+       cpl_propertylist_erase_regexp(*plist, "^CTYPE3",0);
+    }
+    cpl_propertylist_insert_after_string(*plist,"MJD-OBS", "CTYPE3", "WAVE" ) ;
     cpl_propertylist_set_comment(*plist,"CTYPE3","wavelength axis in microns") ;
 
-    cpl_propertylist_erase_regexp(*plist, "^CRPIX3",0);
+    if(cpl_propertylist_has(*plist,"CRPIX3")) {
+       cpl_propertylist_erase_regexp(*plist, "^CRPIX3",0);
+    }
     cpl_propertylist_insert_after_double(*plist,"CTYPE3","CRPIX3", (double)crpix3 ) ;
     cpl_propertylist_set_comment(*plist, "CRPIX3", "Reference pixel in z") ;
 
-    cpl_propertylist_erase_regexp(*plist, "^CRVAL3",0);
+    if(cpl_propertylist_has(*plist,"CRVAL3")) {
+       cpl_propertylist_erase_regexp(*plist, "^CRVAL3",0);
+    }
     cpl_propertylist_insert_after_double(*plist,"CRPIX3", "CRVAL3", crval3) ;
     cpl_propertylist_set_comment(*plist, "CRVAL3", "central wavelength") ;
 
-    cpl_propertylist_erase_regexp(*plist, "^CDELT3",0);
-
+    if(cpl_propertylist_has(*plist,"CDELT3")) {
+       cpl_propertylist_erase_regexp(*plist, "^CDELT3",0);
+    }
     cpl_propertylist_insert_after_double(*plist,"CRVAL3","CDELT3",cdelt3) ;
     cpl_propertylist_set_comment(*plist, "CDELT3", "microns per pixel") ;
 
-    cpl_propertylist_erase_regexp(*plist, "^CUNIT3",0);
+    if(cpl_propertylist_has(*plist,"CUNIT3")) {
+       cpl_propertylist_erase_regexp(*plist, "^CUNIT3",0);
+    }
     cpl_propertylist_insert_after_string(*plist,"CDELT3", "CUNIT3", "um" ) ;
     cpl_propertylist_set_comment(*plist, "CUNIT3",  "spectral unit" ) ;
 
-    cpl_propertylist_erase_regexp(*plist, "^SPECSYS",0);
+    if(cpl_propertylist_has(*plist,"SPECSYS")) {
+       cpl_propertylist_erase_regexp(*plist, "^SPECSYS",0);
+    }
     cpl_propertylist_insert_after_string(*plist,"CUNIT3", "SPECSYS", "TOPOCENT" ) ;
     cpl_propertylist_set_comment(*plist, "SPECSYS",  "Coordinate reference frame" ) ;
+
 }
 
 
@@ -1121,31 +1159,26 @@ sinfo_set_cd_matrix2(cpl_propertylist** plist,
             const double cd2_2)
 {
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD1_1",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist,"EXPTIME",
-						     "CD1_1", cd1_1 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD1_1",
-					     "CD rotation matrix" )) ;
+    cpl_propertylist_erase_regexp(*plist, "^CD1_1",0);
+    cpl_propertylist_insert_after_double(*plist,"MJD-OBS","CD1_1", cd1_1 ) ;
+    cpl_propertylist_set_comment(*plist, "CD1_1","CD rotation matrix" ) ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD1_2",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist, "CD1_1",
-						     "CD1_2", cd1_2 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD1_2",
-					     "CD rotation matrix" )) ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD2_1",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist, "CD1_2",
-						     "CD2_1", cd2_1 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD2_1",
-					     "CD rotation matrix" )) ;
+    cpl_propertylist_erase_regexp(*plist, "^CD1_2",0);
+    cpl_propertylist_insert_after_double(*plist, "CD1_1","CD1_2", cd1_2 ) ;
+    cpl_propertylist_set_comment(*plist, "CD1_2","CD rotation matrix" ) ;
+
+
+    cpl_propertylist_erase_regexp(*plist, "^CD2_1",0);
+    cpl_propertylist_insert_after_double(*plist, "CD1_2","CD2_1", cd2_1 ) ;
+    cpl_propertylist_set_comment(*plist, "CD2_1","CD rotation matrix" ) ;
+
+
+    cpl_propertylist_erase_regexp(*plist, "^CD2_2",0);
+    cpl_propertylist_insert_after_double(*plist, "CD2_1","CD2_2", cd2_2 ) ;
+    cpl_propertylist_set_comment(*plist, "CD2_2","CD rotation matrix" ) ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD2_2",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist, "CD2_1",
-						     "CD2_2", cd2_2 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD2_2",
-					     "CD rotation matrix" )) ;
 
- cleanup:
     return;
 
 
@@ -1173,41 +1206,29 @@ sinfo_set_cd_matrix3(cpl_propertylist** plist,
                      const double cd3_3)
 {
 
+    cpl_propertylist_erase_regexp(*plist, "^CD1_3",0);
+    cpl_propertylist_insert_after_double(*plist,"MJD-OBS","CD1_3", cd1_3 ) ;
+    cpl_propertylist_set_comment(*plist, "CD1_3","CD rotation matrix" )  ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD1_3",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist,"EXPTIME",
-						     "CD1_3", cd1_3 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD1_3",
-					     "CD rotation matrix" )) ;
+    cpl_propertylist_erase_regexp(*plist, "^CD2_3",0);
+    cpl_propertylist_insert_after_double(*plist,"CD1_3","CD2_3", cd2_3 ) ;
+    cpl_propertylist_set_comment(*plist, "CD2_3","CD rotation matrix" ) ;
+
+    cpl_propertylist_erase_regexp(*plist, "^CD3_1",0);
+    cpl_propertylist_insert_after_double(*plist,"CD2_3", "CD3_1", cd3_1 ) ;
+    cpl_propertylist_set_comment(*plist, "CD3_1", "CD rotation matrix" ) ;
 
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD2_3",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist,"CD1_3",
-						     "CD2_3", cd2_3 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD2_3",
-					     "CD rotation matrix" )) ;
+    cpl_propertylist_erase_regexp(*plist, "^CD3_2",0);
+    cpl_propertylist_insert_after_double(*plist, "CD3_1","CD3_2", cd3_2 ) ;
+    cpl_propertylist_set_comment(*plist, "CD3_2","CD rotation matrix" ) ;
 
 
+    cpl_propertylist_erase_regexp(*plist, "^CD3_3",0);
+    cpl_propertylist_insert_after_double(*plist, "CD3_2","CD3_3", cd3_3 ) ;
+    cpl_propertylist_set_comment(*plist, "CD3_3","CD rotation matrix" ) ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD3_1",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist,"CD2_3",
-						     "CD3_1", cd3_1 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD3_1",
-					     "CD rotation matrix" )) ;
 
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD3_2",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist, "CD3_1",
-						     "CD3_2", cd3_2 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD3_2",
-					     "CD rotation matrix" )) ;
-
-    check_nomsg(cpl_propertylist_erase_regexp(*plist, "^CD3_3",0));
-    check_nomsg(cpl_propertylist_insert_after_double(*plist, "CD3_2",
-						     "CD3_3", cd3_3 )) ;
-    check_nomsg(cpl_propertylist_set_comment(*plist, "CD3_3",
-					     "CD rotation matrix" )) ;
-
- cleanup:
     return;
 
 
@@ -1230,7 +1251,7 @@ sinfo_set_spect_coord1(cpl_propertylist** plist,
 {
 
     cpl_propertylist_erase_regexp(*plist, "^CTYPE1",0);
-    cpl_propertylist_insert_after_string(*plist,"EXPTIME",  "CTYPE1", "PIXEL");
+    cpl_propertylist_insert_after_string(*plist,"MJD-OBS",  "CTYPE1", "PIXEL");
     cpl_propertylist_set_comment(*plist, "CTYPE1", "Pixel coordinate system.");
 
     cpl_propertylist_erase_regexp(*plist, "^CRPIX1",0);
@@ -1272,13 +1293,15 @@ sinfo_set_spect_coord2(cpl_propertylist** plist,
 {
 
     cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
-    cpl_propertylist_insert_after_string(*plist, "EXPTIME","CTYPE2","WAVE" );
+    cpl_propertylist_insert_after_string(*plist, "MJD-OBS","CTYPE2","WAVE" );
     cpl_propertylist_set_comment(*plist,"CTYPE2","wavelength axis in microns");
 
+
     cpl_propertylist_erase_regexp(*plist, "^CRPIX2",0);
     cpl_propertylist_insert_after_double(*plist, "CTYPE2",  "CRPIX2",(double)crpix2 ) ;
     cpl_propertylist_set_comment(*plist, "CRPIX2", "Reference pixel in x") ;
 
+
     cpl_propertylist_erase_regexp(*plist, "^CRVAL2",0);
     cpl_propertylist_insert_after_double(*plist, "CRPIX2","CRVAL2",crval2 ) ;
     cpl_propertylist_set_comment(*plist,"CRVAL2", "central wavelength") ;
@@ -1337,9 +1360,6 @@ sinfo_new_change_plist_spectrum (cpl_propertylist * plist,
   cpl_propertylist_erase_regexp(plist, "^CD2_1",0);
   cpl_propertylist_erase_regexp(plist, "^CD2_2",0);
 
-
-
-
   sinfo_set_spect_coord1(&plist,crpix1,crval1,cdelt1);
   sinfo_set_spect_coord2(&plist,crpix2,crval2,cdelt2);
 
@@ -1433,54 +1453,30 @@ sinfo_new_change_plist_image (cpl_propertylist * plist,
  cleanup:
     return;
 }
-
 /**
-@brief subtract from each cube's plane its median
-@name sinfo_new_sinfoni_correct_median
-@param cubes input imagelist
-@param n_cubes number of cubes
-*/
-/* TODO: not used */
-cpl_imagelist**
-sinfo_new_sinfoni_correct_median(cpl_imagelist** cubes, const int n_cubes)
-{
-  int i=0;
-  cpl_imagelist** cubes_cor=NULL;
-  double local_median=0;
-  int z=0;
-  cpl_image* i_img=NULL;
-  cpl_image* o_img=NULL;
+@brief subtract from e
+        cpl_propertylist_erase_regexp(*plist, "^CTYPE2",0);
+        cpl_propertylist_insert_after_string(*plist, "MJD-OBS","CTYPE2","WAVE" );
+        cpl_propertylist_set_comment(*plist,"CTYPE2","wavelength axis in microns");
 
 
-  if ( cubes == NULL ) {
-    sinfo_msg_error ("no cube list given!") ;
-    return NULL ;
-  }
-  if ( n_cubes <= 0 ) {
-    sinfo_msg_error ("wrong number of data cubes in list!") ;
-    return NULL ;
-  }
+        cpl_propertylist_erase_regexp(*plist, "^CRPIX2",0);
+        cpl_propertylist_insert_after_double(*plist, "CTYPE2",  "CRPIX2",(double)crpix2 ) ;
+        cpl_propertylist_set_comment(*plist, "CRPIX2", "Reference pixel in x") ;
 
-  cubes_cor = (cpl_imagelist**) cpl_calloc (n_cubes, sizeof (cpl_imagelist*)) ;
 
-  for ( i = 0 ; i < n_cubes ; i++ ) {
-    cubes_cor[i] = cpl_imagelist_new();
-    for(z=0;z< cpl_imagelist_get_size(cubes[i]); z++) {
-      i_img=cpl_imagelist_get(cubes[i],z);
-      local_median=cpl_image_get_median(i_img);;
-      o_img=cpl_image_duplicate(i_img);
-      if(!isnan(local_median)) {
-        cpl_image_subtract_scalar(o_img,local_median);
-       }
-      cpl_imagelist_set(cubes_cor[i],o_img,z);
-    }
-  }
+        cpl_propertylist_erase_regexp(*plist, "^CRVAL2",0);
+        cpl_propertylist_insert_after_double(*plist, "CRPIX2","CRVAL2",crval2 ) ;
+        cpl_propertylist_set_comment(*plist,"CRVAL2", "central wavelength") ;
 
-  return cubes_cor;
-}
+        cpl_propertylist_erase_regexp(*plist, "^CDELT2",0);
+        cpl_propertylist_insert_after_double(*plist, "CRVAL2", "CDELT2",cdelt2);
+        cpl_propertylist_set_comment(*plist,"CDELT2", "microns per pixel");
 
-/**
-@brief subtract from each cube's plane its median
+        cpl_propertylist_erase_regexp(*plist, "^CUNIT2",0);
+        cpl_propertylist_insert_after_string(*plist,"CDELT2",  "CUNIT2", "um");
+        cpl_propertylist_set_comment(*plist, "CUNIT2",  "spectral unit" );
+   ach cube's plane its median
 @name sinfo_new_sinfoni_correct_median_it
 @param inp input imagelist
 */
@@ -1502,318 +1498,6 @@ int sinfo_new_sinfoni_correct_median_it(cpl_imagelist** inp)
   return 0;
 }
 
-/**
-@brief subtract from each object cube's plane each sky cube's
-       plane and return the sky cube
-@name sinfo_new_sinfoni_correct_sky
-@param inp input imagelist
-@param nc  size of cube
-@param sky_cube output sky cube
-*/
-/* TODO: not used */
-cpl_imagelist** sinfo_new_sinfoni_correct_sky(cpl_imagelist** cubes,
-                  const int nc,
-                  cpl_imagelist* sky_cube)
-
-{
-  cpl_imagelist** cubes_sky=NULL;
-  int x=0;
-  int y=0;
-  int z=0;
-  int i=0;
-  float k=0.5;
-  int ovr=0;
-  int ks=0;
-  int nclip=0;
-  double med=0;
-  double avg=0;
-  double sig=0;
-  int msk_sum=0;
-  double val_msk_sum=0;
-  cpl_vector* val=NULL;
-  cpl_vector* msk=NULL;
-  int ilx=0;
-  int ily=0;
-  int inp=0;
-
-
-  int sky_lx=0;
-  /* int sky_ly=0; */
-
-
-  cpl_image* i_img=NULL;
-
-
-
-  if ( cubes == NULL ) {
-    sinfo_msg_error ("no cube list given!") ;
-    return NULL ;
-  }
-  ilx=cpl_image_get_size_x(cpl_imagelist_get(cubes[0],0));
-  ily=cpl_image_get_size_y(cpl_imagelist_get(cubes[0],0));
-  inp=cpl_imagelist_get_size(cubes[0]);
-
-
-  sky_lx=cpl_image_get_size_x(cpl_imagelist_get(sky_cube,0));
-  /* sky_ly=cpl_image_get_size_y(cpl_imagelist_get(sky_cube,0)); */
-  if ( nc <= 0 ) {
-    sinfo_msg_error ("wrong number of data cubes in list!") ;
-    return NULL ;
-  }
-
-  cubes_sky = (cpl_imagelist**) cpl_calloc (nc, sizeof (cpl_imagelist*)) ;
-  float* pidata;
-  for(z=0;z< inp; z++) {
-    cpl_image* sky_img=cpl_imagelist_get(sky_cube,z);
-    float* p_sky_data=cpl_image_get_data_float(sky_img);
-    for(y=0;y< ily; y++) {
-      for(x=0;x< ilx; x++) {
-        /* here we start to do a k-s clipping */
-    msk=cpl_vector_new(nc);
-    for (i=0;i<nc;i++) {
-      cpl_vector_set(msk,i,1);
-    }
-        nclip=0;
-        for (ks=0;ks<nc;ks++) {
-      sig=0;
-      med=0;
-      ovr=0;
-      val=cpl_vector_new(nc-nclip);
-
-      for ( i = 0 ; i < nc ; i++ ) {
-            i_img=cpl_imagelist_get(cubes[i],z);
-            pidata=cpl_image_get_data_float(i_img);
-        if ((!isnan(pidata[x+y*ilx])) &&
-                 (cpl_vector_get(msk,i) != 0) ) {
-          cpl_vector_set(val,ovr,(double)pidata[x+y*ilx]);
-          ovr++;
-        }
-      }
-
-      if(ovr>0) {
-        avg=cpl_vector_get_mean(val);
-        med=cpl_vector_get_median_const(val);
-        if(ovr>1) {
-          sig=cpl_vector_get_stdev(val);
-        } else {
-              sig=0;
-        }
-      } else {
-        avg=cpl_vector_get(val,0);
-        med=avg;
-        sig=0;
-      }
-
-      cpl_vector_delete(val);
-      for ( i = 0 ; i < nc ; i++ ) {
-            i_img=cpl_imagelist_get(cubes[i],z);
-            pidata=cpl_image_get_data_float(i_img);
-      /* Do k-s clipping at each pixel */
-        if ((!isnan(pidata[x+y*ilx])) &&
-                (cpl_vector_get(msk,i) != 0)) {
-          if(abs((pidata[x+y*ilx]-med))> k*sig) {
-        cpl_vector_set(msk,i,0);
-                nclip++;
-          }
-        }
-      }
-    }/* end of k-s clipping */
-    msk_sum=0;
-    val_msk_sum=0;
-    for ( i = 0 ; i < nc ; i++ ) {
-      /* computes sky at each point */
-      if (!isnan(pidata[x+y*ilx])) {
-        msk_sum+=cpl_vector_get(msk,i);
-                val_msk_sum+=pidata[x+y*ilx]*
-          cpl_vector_get(msk,i);
-      }
-    }
-    p_sky_data[x+y*sky_lx]=val_msk_sum/msk_sum;
-    cpl_vector_delete(msk);
-      } /* end loop over x */
-    } /* end loop over y */
-  } /* end loop over z */
-  for ( i = 0 ; i < nc ; i++ ) {
-    cubes_sky[i]=cpl_imagelist_duplicate(cubes[i]);
-    /* subtract the variable clean sky */
-    cpl_imagelist_subtract(cubes_sky[i],sky_cube);
-
-  }
-
-
-  return cubes_sky;
-}
-
-/**
-@brief subtract from each object cube's plane each sky cube's plane and
-       output a sky, a median, a mask, an average, a sigma and and
-       overlapping imagelist
-@name sinfo_new_sinfoni_correct_sky2
-@param inp input imagelist
-@param nc  size of imagelist
-@param sky_cube sky
-@param med_cube median
-@param msk_cube mask
-@param avg_cube average
-@param sig_cube sigma
-@param ovr_cube overlapping points
-*/
-/* TODO: not used */
-cpl_imagelist** sinfo_new_sinfoni_correct_sky2(cpl_imagelist** cubes,
-                  const int nc,
-                  cpl_imagelist* sky_cube,
-                              cpl_imagelist* med_cube,
-                              cpl_imagelist* msk_cube,
-                              cpl_imagelist* avg_cube,
-                              cpl_imagelist* sig_cube,
-                              cpl_imagelist* ovr_cube)
-{
-  cpl_imagelist** cubes_sky=NULL;
-  int x=0;
-  int y=0;
-  int z=0;
-  int i=0;
-  float k=0.5;
-  int ovr=0;
-  int ks=0;
-  int nclip=0;
-  double med=0;
-  double avg=0;
-  double sig=0;
-  int msk_sum=0;
-  double val_msk_sum=0;
-  cpl_vector* val=NULL;
-  cpl_vector* msk=NULL;
-
-  int ilx=0;
-  int ily=0;
-  int inp=0;
-
-  int ovr_lx=0;
-  int msk_lx=0;
-  int avg_lx=0;
-  int sig_lx=0;
-  int sky_lx=0;
-  int med_lx=0;
-
-  float* pidata=NULL;
-
-  if ( cubes == NULL ) {
-    sinfo_msg_error ("no cube list given!") ;
-    return NULL ;
-  }
-
-  ilx=cpl_image_get_size_x(cpl_imagelist_get(cubes[0],0));
-  ily=cpl_image_get_size_y(cpl_imagelist_get(cubes[0],0));
-  inp=cpl_imagelist_get_size(cubes[0]);
-
-  if ( nc <= 0 ) {
-    sinfo_msg_error ("wrong number of data cubes in list!") ;
-    return NULL ;
-  }
-
-  cubes_sky = (cpl_imagelist**) cpl_calloc (nc, sizeof (cpl_imagelist*)) ;
-
-  ovr_lx=ilx;
-  msk_lx=ilx;
-  avg_lx=ilx;
-  sig_lx=ilx;
-  sky_lx=ilx;
-  med_lx=ilx;
-
-  for(z=0;z< inp; z++) {
-    float* p_ovr_data=cpl_image_get_data_float(cpl_imagelist_get(ovr_cube,z));
-    float* p_msk_data=cpl_image_get_data_float(cpl_imagelist_get(msk_cube,z));
-    float* p_avg_data=cpl_image_get_data_float(cpl_imagelist_get(avg_cube,z));
-    float* p_sig_data=cpl_image_get_data_float(cpl_imagelist_get(sig_cube,z));
-    float* p_sky_data=cpl_image_get_data_float(cpl_imagelist_get(sky_cube,z));
-    float* p_med_data=cpl_image_get_data_float(cpl_imagelist_get(med_cube,z));
-
-
-    for(y=0;y< ily; y++) {
-      for(x=0;x< ilx; x++) {
-        /* here we start to do a k-s clipping */
-    msk=cpl_vector_new(nc);
-    for (i=0;i<nc;i++) {
-      cpl_vector_set(msk,i,1);
-    }
-    p_ovr_data[x+y*ovr_lx]=nc;
-    p_msk_data[x+y*msk_lx]=nc;
-        nclip=0;
-        for (ks=0;ks<nc;ks++) {
-      sig=0;
-      med=0;
-      ovr=0;
-      val=cpl_vector_new(nc-nclip);
-
-      for ( i = 0 ; i < nc ; i++ ) {
-            pidata=cpl_image_get_data_float(cpl_imagelist_get(cubes[i],z));
-        if ((!isnan(pidata[x+y*ilx])) &&
-                 (cpl_vector_get(msk,i) != 0) ) {
-          cpl_vector_set(val,ovr,(double)pidata[x+y*ilx]);
-          ovr++;
-        }
-      }
-
-      if(ovr>1) {
-        avg=cpl_vector_get_mean(val);
-        med=cpl_vector_get_median_const(val);
-        sig=cpl_vector_get_stdev(val);
-      } else {
-        avg=cpl_vector_get(val,0);
-        med=avg;
-        sig=0;
-      }
-
-      p_med_data[x+y*med_lx]=med;
-      p_avg_data[x+y*avg_lx]=avg;
-      p_sig_data[x+y*sig_lx]=sig;
-      cpl_vector_delete(val);
-      for ( i = 0 ; i < nc ; i++ ) {
-           pidata=cpl_image_get_data_float(cpl_imagelist_get(cubes[i],z));
-      /* Do k-s clipping at each pixel */
-        if ((!isnan(pidata[x+y*ilx])) &&
-                (cpl_vector_get(msk,i) != 0)) {
-          if(abs((pidata[x+y*ilx]-med))> k*sig) {
-        /* pidata[x+y*ilx]=0; */
-        p_msk_data[x+y*msk_lx]-=1;
-        cpl_vector_set(msk,i,0);
-                nclip++;
-          }
-        }
-      }
-    }/* end of k-s clipping */
-    msk_sum=0;
-    val_msk_sum=0;
-    for ( i = 0 ; i < nc ; i++ ) {
-           pidata=cpl_image_get_data_float(cpl_imagelist_get(cubes[i],z));
-      /* computes sky at each point */
-      if (!isnan(pidata[x+y*ilx])) {
-        /*
-        msk_sum+=p_msk_data[x+y*msk_lx];
-                val_msk_sum+=pidata[x+y*cubes[i]->lx]*
-          p_msk_data[x+y*msk_lx];
-        */
-        msk_sum+=cpl_vector_get(msk,i);
-                val_msk_sum+=pidata[x+y*ilx]*
-          cpl_vector_get(msk,i);
-      }
-    }
-    p_sky_data[x+y*sky_lx]=val_msk_sum/msk_sum;
-    cpl_vector_delete(msk);
-      } /* end loop over x */
-    } /* end loop over y */
-  } /* end loop over z */
-  for ( i = 0 ; i < nc ; i++ ) {
-    cubes_sky[i]=cpl_imagelist_duplicate(cubes[i]);
-    /* subtract the variable clean sky */
-    cpl_imagelist_subtract(cubes_sky[i],sky_cube);
-  }
-
-
-  return cubes_sky;
-}
-
 static void
 sinfo_set_offset_xy(double mjd_obs,
                     const double offx, const double offy,const int n,
