@@ -690,11 +690,18 @@ int sinfo_new_find_lines(cpl_image * lineImage,
                             dispersion2 * (float) (i-ly/2) *
                             (float) (i-ly/2) +
                             beginWave) * angst ;
-
+            /*
+            sinfo_msg("wo=%g d1=%g d2=%g angst=%g lines[i]=%g",
+                      beginWave,dispersion1,dispersion2,angst,lines[i]);
+                      */
             /* ---------------------------------------------------------------
              * find the nearest line position for each wavelength in the list 
              * and set this position to the given line intensity as weight 
              */
+            /*
+            sinfo_msg("dispersion1 =%g dispersion2=%g dispersion0=%g ly/2=%d",
+                      dispersion1,dispersion2,beginWave,ly/2);
+            */
             for ( j = 0 ; j < n_lines ; j ++ )
             {
                 buf1 = 0. ;
@@ -707,10 +714,13 @@ int sinfo_new_find_lines(cpl_image * lineImage,
                     buf1 = wave_intensity[j] ; /* set the given line intensity 
                                                   as weight */
                     buf2 = wave_position[j] ;
+                    //sinfo_msg("line posx=%d posy=%d wave=%g",col,i,buf2);
                     break ;
                 }
             }
+
             lines[i] = buf1 ;
+
             wave_buffer[i] = buf2 ; /* get the wavelength associated 
                                        with the corresponding 
                                            found emission line */
@@ -1137,6 +1147,8 @@ int sinfo_new_fit_lines ( cpl_image  *  line_image,
             {
                 sinfo_msg_warning (" negative fit parameters in column: %d,"
                                 " line: %d\n", i, l) ;
+                sinfo_msg_warning("f0=%g f1=%g f2=%g",
+                                   allParams[k] -> fit_par[0],allParams[k] -> fit_par[1],allParams[k] -> fit_par[2]);
                 continue ;
             }
             allParams[k] -> wavelength = wavelength[i][l] ;
