@@ -651,6 +651,8 @@ cpl_image * sinfo_new_wave_cal( cpl_image   * image,
                                 float        pixel_tolerance )
 
 {
+    sinfo_msg("pixel_dist=%g",pixel_dist);
+    //exit(0);
     int          i=0, j=0;
     /* int k=0 ; */
     int          n_fit=0 ;
@@ -1847,10 +1849,17 @@ float sinfo_new_check_line_positions ( cpl_image     * lineIm,
             found = -1 ;
             for ( i = 0 ; i < par[0]->n_params ; i++ )
             {
+
                 if (par[i]->column == col && par[i]->fit_par[2] != 0. && 
                                 par[i]->fit_par[1] > 1. && par[i]->fit_par[1] < 7. &&
                                 par[i]->line == lin )
+
                 {
+		  /*
+                    sinfo_msg("wavelength=%g col=%d par[i]->column=%d GaussCenter=%g GaussFWHM=%g par[i]->line=%g lin=%d",
+                               par[i]->wavelength,col,par[i]->column,par[i]->fit_par[2],par[i]->fit_par[1],par[i]->line,lin);
+		  */
+
                     found = i ;
                 }
             }
@@ -2144,8 +2153,10 @@ float sinfo_new_check_correlated_line_positions ( cpl_image     * lineIm,
             if ( (par[k] -> fit_par[0] <= 0.) || (par[k] -> fit_par[1] <= 0.)
                             || (par[k] -> fit_par[2] <= 0.) )
             {
+
                 sinfo_msg_warning ("negative fit parameters in column: %d, "
                                 "line: %d\n", col, line) ;
+
                 continue ;
             }
             par[k] -> wavelength = wavelength[line] ;
@@ -2211,6 +2222,7 @@ float sinfo_new_check_correlated_line_positions ( cpl_image     * lineIm,
     }
 
     /* determine positioning error for each found line */
+    sinfo_msg("n_lines=%d",n_lines);
     for ( line = 0 ; line < n_lines ; line++ )
     {
         if (line > 0 && line < n_lines-1)
